@@ -19,7 +19,6 @@ from AbstractApp import AbstractApp
 from Setting import Setting
 from SetEditor import SetEditor
 from ColorEditor import ColorEditor
-from Demo import Demo
 
 import Pmw
 import sys, string
@@ -47,8 +46,8 @@ def complete(event,str,widget,self):
 
 class PMGApp(AbstractApp):
 
-   appversion     = '0.86'
-   appname       = 'PyMOL Molecular Graphics System'
+   appversion     = '0.88'
+   appname       = 'PyMOL Tcl/Tk GUI'
    copyright      = 'Copyright (C) 1998-2002 by Warren DeLano of\nDeLano Scientific LLC. All rights reserved.'
    contactweb     = 'http://www.pymol.org'
    contactemail   = 'warren@delanoscientific.com'
@@ -160,13 +159,17 @@ class PMGApp(AbstractApp):
          self.history[0] = self.command.get()
       self.history_cur = (self.history_cur + 1) & self.history_mask
       self.command.set(self.history[self.history_cur])
+      l = len(self.history[self.history_cur])
+      self.entry.icursor(l)
    
    def forward(self):
       if not self.history_cur:
          self.history[0] = self.command.get()
       self.history_cur = (self.history_cur - 1) & self.history_mask
       self.command.set(self.history[self.history_cur])
-   
+      l = len(self.history[self.history_cur])
+      self.entry.icursor(l)
+      
    def do(self,cmmd):
       self.history[0]=cmmd
       self.history.insert(0,'') # always leave blank at 0
@@ -190,6 +193,7 @@ class PMGApp(AbstractApp):
                       e=self.entry,s=self:
                       complete(event,w,e,s))
 
+
       self.history_mask = 0xFF
       self.history = [''] * (self.history_mask+1)
       self.history_cur = 0
@@ -225,6 +229,32 @@ class PMGApp(AbstractApp):
       self.initialdir = os.getcwd()
       self.log_file = "log.pml"
 
+
+      self.bind_all('<F1>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(1,0,0)"))
+      self.bind_all('<F2>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(2,0,0)"))
+      self.bind_all('<F3>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(3,0,0)"))
+      self.bind_all('<F4>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(4,0,0)"))
+      self.bind_all('<F5>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(5,0,0)"))
+      self.bind_all('<F6>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(6,0,0)"))
+      self.bind_all('<F7>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(7,0,0)"))
+      self.bind_all('<F8>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(8,0,0)"))
+      self.bind_all('<F9>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(9,0,0)"))
+      self.bind_all('<F10>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special_special(10,0,0)"))
+      self.bind_all('<F11>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special_special(11,0,0)"))
+      self.bind_all('<F12>',lambda event,w=self.command,
+                      e=self.entry,s=self:cmd.do("cmd._special(12,0,0)"))
+
    def flush_commands(self):
       # flush the external GUI fifo command queue
       while not self.fifo.empty():
@@ -259,12 +289,12 @@ class PMGApp(AbstractApp):
          self.createButtons()
          self.createMain()
          self.lineCount = 0
-         startup_pattern = re.sub(r"\/[^\/]*$","/startup/*.py*",__file__)
+         startup_pattern = re.sub(r"[\/\\][^\/\\]*$","/startup/*.py*",__file__)
          # startup_pattern = os.environ['PYMOL_PATH']+"/modules/pmg_tk/startup/*.py*"
          raw_list = glob(startup_pattern)
          unique = {}
          for a in raw_list:
-            unique[re.sub(r".*\/|\.py.*$","",a)] = 1
+            unique[re.sub(r".*[\/\\]|\.py.*$","",a)] = 1
          for name in unique.keys():
             if name != "__init__":
                mod_name = "pmg_tk.startup."+name
@@ -687,8 +717,12 @@ class PMGApp(AbstractApp):
                                label='Make (pk1) Neutral',
                                command = lambda: cmd.do("_ alter pk1,formal_charge=-0.0"))
 
+      self.menuBar.addmenu('Build', 'Build',tearoff=TRUE)
 
-      self.menuBar.addmenu('Fragment', 'Fragment')
+      self.menuBar.addcascademenu('Build', 'Fragment', 'Fragment',
+                                  label='Fragment',tearoff=TRUE)
+      
+#      self.menuBar.addmenu('Fragment', 'Fragment')
 
       self.menuBar.addmenuitem('Fragment', 'command', 'Acetylene',
                                label='Acetylene [Alt-J]',
@@ -786,8 +820,12 @@ class PMGApp(AbstractApp):
                                label='Phosphorus [Ctrl-P]',
                                command = lambda: cmd.do("_ replace P,4,3"))
 
-      self.menuBar.addmenu('Residue', 'Residue')
+#      self.menuBar.addmenu('Residue', 'Residue')
 
+      self.menuBar.addcascademenu('Build', 'Residue', 'Residue',
+                                  label='Residue',tearoff=TRUE)
+
+ 
       self.menuBar.addmenuitem('Residue', 'command', 'Acetyl',
                                label='Acetyl [Alt-B]',
                                command = lambda: cmd.do(
@@ -912,7 +950,7 @@ class PMGApp(AbstractApp):
                                label='Parallel Beta Sheet',
                                command = lambda: cmd.do("_ set secondary_structure,3"))
 
-      self.menuBar.addmenu('Movie', 'Movie Control')
+      self.menuBar.addmenu('Movie', 'Movie Control',tearoff=TRUE)
 
       
       self.menuBar.addcascademenu('Movie', 'Speed', 'Playback Speed',
@@ -978,8 +1016,175 @@ class PMGApp(AbstractApp):
                         variable = self.setting.all_states,
                         command = lambda s=self: s.setting.update('all_states'))
 
+      self.menuBar.addmenu('Display', 'Display Control',tearoff=TRUE)
+      
+      self.menuBar.addmenuitem('Display', 'command', 'Stereo On',
+                               label='Stereo On',
+                               command = lambda: cmd.do("_ stereo on"))
 
-      self.menuBar.addmenu('Rendering', 'Rendering Control')
+      self.menuBar.addmenuitem('Display', 'command', 'Stereo Off',
+                               label='Stereo Off',
+                               command = lambda: cmd.do("_ stereo off"))
+
+      self.menuBar.addcascademenu('Display', 'Stereo', 'Stereo',
+                               label='Stereo')
+
+      self.menuBar.addmenuitem('Stereo', 'command', 'Cross-Eye Stereo',
+                               label='Cross-Eye Stereo',
+                               command = lambda: cmd.do("_ stereo crosseye"))
+
+      self.menuBar.addmenuitem('Stereo', 'command', 'Wall-Eye Stereo',
+                               label='Wall-Eye Stereo',
+                               command = lambda: cmd.do("_ stereo walleye"))
+
+      self.menuBar.addmenuitem('Stereo', 'command', 'Quad-Buffered Stereo',
+                               label='Quad-Buffered Stereo',
+                               command = lambda: cmd.do("_ stereo quadbuffer"))
+
+      self.menuBar.addmenuitem('Stereo', 'separator', '')
+
+      self.menuBar.addmenuitem('Stereo', 'command', 'Swap Sides',
+                               label='Swap Sides',
+                               command = lambda: cmd.do("_ stereo swap"))
+
+      self.menuBar.addmenuitem('Display', 'separator', '')
+
+
+      self.menuBar.addcascademenu('Display', 'Zoom', 'Zoom',
+                                  label='Zoom')
+
+
+      self.menuBar.addmenuitem('Zoom', 'command', '4 Angstrom Sphere',
+                               label='4 Angstrom Sphere',
+                               command = lambda: cmd.do("_ zoom center,4"))
+
+      self.menuBar.addmenuitem('Zoom', 'command', '6 Angstrom Sphere',
+                               label='6 Angstrom Sphere',
+                               command = lambda: cmd.do("_ zoom center,6"))
+
+      self.menuBar.addmenuitem('Zoom', 'command', '8 Angstrom Sphere',
+                               label='8 Angstrom Sphere',
+                               command = lambda: cmd.do("_ zoom center,8"))
+
+      self.menuBar.addmenuitem('Zoom', 'command', '12 Angstrom Sphere',
+                               label='12 Angstrom Sphere',
+                               command = lambda: cmd.do("_ zoom center,12"))
+
+      self.menuBar.addmenuitem('Zoom', 'command', '20 Angstrom Sphere',
+                               label='20 Angstrom Sphere',
+                               command = lambda: cmd.do("_ zoom center,20"))
+
+      self.menuBar.addmenuitem('Zoom', 'command', 'All',
+                               label='All',
+                               command = lambda: cmd.do("_ zoom all"))
+
+      self.menuBar.addcascademenu('Display', 'Clip', 'Clip',
+                                  label='Clip')
+
+      self.menuBar.addmenuitem('Clip', 'command', 'None',
+                               label='None',
+                               command = lambda: cmd.do("_ clip atoms,5,all"))
+
+      self.menuBar.addmenuitem('Clip', 'command', '8 Angstrom Slab',
+                               label='8 Angstrom Slab',
+                               command = lambda: cmd.do("_ clip slab,8"))
+
+      self.menuBar.addmenuitem('Clip', 'command', '12 Angstrom Slab',
+                               label='12 Angstrom Slab',
+                               command = lambda: cmd.do("_ clip slab,10"))
+
+      self.menuBar.addmenuitem('Clip', 'command', '16 Angstrom Slab',
+                               label='16 Angstrom Slab',
+                               command = lambda: cmd.do("_ clip slab,15"))
+
+      self.menuBar.addmenuitem('Clip', 'command', '20 Angstrom Slab',
+                               label='20 Angstrom Slab',
+                               command = lambda: cmd.do("_ clip slab,20"))
+
+      self.menuBar.addmenuitem('Clip', 'command', '30 Angstrom Slab',
+                               label='30 Angstrom Slab',
+                               command = lambda: cmd.do("_ clip slab,30"))
+
+
+      self.menuBar.addmenuitem('Display', 'separator', '')
+
+      self.menuBar.addcascademenu('Display', 'Background', 'Background',
+                                  label='Background')
+
+      self.menuBar.addmenuitem('Background', 'command', 'White Background',
+                               label='White',
+                               command = lambda : cmd.do("_ cmd.bg_color('white')"))
+
+      self.menuBar.addmenuitem('Background', 'command', 'Light Grey',
+                               label='Light Grey',
+                               command = lambda : cmd.do("_ cmd.bg_color('grey80')"))
+
+      self.menuBar.addmenuitem('Background', 'command', 'Grey',
+                               label='Grey',
+                               command = lambda : cmd.do("_ cmd.bg_color('grey50')"))
+
+
+      self.menuBar.addmenuitem('Background', 'command', 'Black Background',
+                               label='Black',
+                               command = lambda : cmd.do("_ cmd.bg_color('black')"))
+
+      self.menuBar.addcascademenu('Display', 'Color Space', 'Color Space',
+                                  label='Color Space')
+
+      self.menuBar.addmenuitem('Color Space', 'command', 'CMYK (for publications)',
+                               label='CMYK (for publications)',
+                               command = lambda : cmd.do("_ cmd.space('cmyk')"))
+
+      self.menuBar.addmenuitem('Color Space', 'command', 'PyMOL (for video & web)',
+                               label='PyMOL (for video & web)',
+                               command = lambda : cmd.do("_ cmd.space('pymol')"))
+
+      self.menuBar.addmenuitem('Color Space', 'command', 'RGB (default)',
+                               label='RGB (default)',
+                               command = lambda : cmd.do("_ cmd.space('rgb')"))
+
+      self.menuBar.addcascademenu('Display', 'Performance', 'Performance',
+                                  label='Performance')
+
+      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Performance',
+                               label='Maximum Performance',
+                               command = lambda : cmd.do("_ util.performance(100)"))
+
+      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Performance',
+                               label='Reasonable Performance',
+                               command = lambda : cmd.do("_ util.performance(66)"))
+      
+      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Quality',
+                               label='Reasonable Quality',
+                               command = lambda : cmd.do("_ util.performance(33)"))
+
+      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Quality',
+                               label='Maximum Quality',
+                               command = lambda : cmd.do("_ util.performance(0)"))
+
+      self.menuBar.addcascademenu('Display', 'Transparency', 'Transparency',
+                                  label='Transparency')
+
+
+      self.menuBar.addmenuitem('Transparency', 'command', 'Uni-Layer',
+                               label='Uni-Layer',
+                               command = lambda : cmd.do(
+         "_ cmd.set('transparency_mode',2);cmd.set('backface_cull',1);cmd.set('two_sided_lighting',0)"))
+
+      self.menuBar.addmenuitem('Transparency', 'command', 'Multi-Layer',
+                               label='Multi-Layer',
+                               command = lambda : cmd.do(
+         "_ cmd.set('transparency_mode',1);cmd.set('backface_cull',0);cmd.set('two_sided_lighting',1)"))
+
+      self.menuBar.addmenuitem('Transparency', 'command', 'Fast and Ugly',
+                               label='Fast and Ugly',
+                               command = lambda : cmd.do(
+         "_ cmd.set('transparency_mode',0);cmd.set('backface_cull',1);cmd.set('two_sided_lighting',0)"))
+      
+      self.menuBar.addcascademenu('Display', 'Rendering', 'Rendering',
+                                  label='Rendering')
+
+#     self.menuBar.addmenu('Rendering', 'Rendering Control')
 
       self.menuBar.addmenuitem('Rendering', 'checkbutton',
                          'Smooth raytracing.',
@@ -1043,7 +1248,48 @@ class PMGApp(AbstractApp):
                                label='Fiber',
                                command = lambda : cmd.do("_ cmd.set('ray_texture',5)"))
 
+      self.menuBar.addcascademenu('Rendering', 'Interior Texture', 'Interior Texture',
+                               label=self.pad+'Interior Texture')
 
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'None',
+                               label='None',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',0)"))
+
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'Matte 1',
+                               label='Matte 1',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',1)"))
+
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'Matte 2',
+                               label='Matte 2',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',4)"))
+
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'Swirl 1',
+                               label='Swirl 1',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',2)"))
+
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'Swirl 2',
+                               label='Swirl 2',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',3)"))
+
+      self.menuBar.addmenuitem('Interior Texture', 'command', 'Fiber',
+                               label='Fiber',
+                               command = lambda : cmd.do("_ cmd.set('ray_interior_texture',5)"))
+
+
+      self.menuBar.addcascademenu('Rendering', 'Memory', 'Memory',
+                               label=self.pad+'Memory')
+
+      self.menuBar.addmenuitem('Memory', 'command', 'Use Less (slower)',
+                               label='Use Less (slower)',
+                               command = lambda : cmd.do("_ cmd.set('hash_max',70,quiet=0)"))
+
+      self.menuBar.addmenuitem('Memory', 'command', 'Use Standard Amount',
+                               label='Use Standard Amount',
+                               command = lambda : cmd.do("_ cmd.set('hash_max',100,quiet=0)"))
+
+      self.menuBar.addmenuitem('Memory', 'command', 'Use More (faster)',
+                               label='Use More (faster)',
+                               command = lambda : cmd.do("_ cmd.set('hash_max',160,quiet=0)"))
 
       self.menuBar.addmenuitem('Rendering', 'separator', '')
 
@@ -1053,76 +1299,14 @@ class PMGApp(AbstractApp):
                         variable = self.setting.backface_cull,
                         command = lambda s=self: s.setting.update('backface_cull'))
 
-      self.menuBar.addmenu('Display', 'Display Control')
 
+      self.menuBar.addmenuitem('Rendering', 'checkbutton',
+                         'Opaque Interior Colors',
+                         label=self.pad+'Opaque Interiors',
+                        variable = self.setting.ray_interior_color,
+                        command = lambda s=self: s.setting.update('ray_interior_color'))
 
       
-      self.menuBar.addmenuitem('Display', 'command', 'Stereo On',
-                               label='Stereo On',
-                               command = lambda: cmd.do("_ stereo on"))
-
-      self.menuBar.addmenuitem('Display', 'command', 'Stereo Off',
-                               label='Stereo Off',
-                               command = lambda: cmd.do("_ stereo off"))
-
-      self.menuBar.addcascademenu('Display', 'Stereo', 'Stereo',
-                               label='Stereo')
-
-      self.menuBar.addmenuitem('Stereo', 'command', 'Cross-Eye Stereo',
-                               label='Cross-Eye Stereo',
-                               command = lambda: cmd.do("_ stereo crosseye"))
-
-      self.menuBar.addmenuitem('Stereo', 'command', 'Quad-Buffered Stereo',
-                               label='Quad-Buffered Stereo',
-                               command = lambda: cmd.do("_ stereo quadbuffer"))
-
-      self.menuBar.addmenuitem('Stereo', 'separator', '')
-
-      self.menuBar.addmenuitem('Stereo', 'command', 'Swap Sides',
-                               label='Swap Sides',
-                               command = lambda: cmd.do("_ stereo swap"))
-
-      self.menuBar.addmenuitem('Display', 'separator', '')
-
-      self.menuBar.addcascademenu('Display', 'Performance', 'Performance',
-                                  label='Performance')
-
-      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Performance',
-                               label='Maximum Performance',
-                               command = lambda : cmd.do("_ util.performance(100)"))
-
-      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Performance',
-                               label='Reasonable Performance',
-                               command = lambda : cmd.do("_ util.performance(66)"))
-      
-      self.menuBar.addmenuitem('Performance', 'command', 'Reasonable Quality',
-                               label='Reasonable Quality',
-                               command = lambda : cmd.do("_ util.performance(33)"))
-
-      self.menuBar.addmenuitem('Performance', 'command', 'Maximum Quality',
-                               label='Maximum Quality',
-                               command = lambda : cmd.do("_ util.performance(0)"))
-
-      self.menuBar.addcascademenu('Display', 'Background', 'Background',
-                                  label='Background')
-
-      self.menuBar.addmenuitem('Background', 'command', 'White Background',
-                               label='White',
-                               command = lambda : cmd.do("_ cmd.bg_color('white')"))
-
-      self.menuBar.addmenuitem('Background', 'command', 'Light Grey',
-                               label='Light Grey',
-                               command = lambda : cmd.do("_ cmd.bg_color('grey80')"))
-
-      self.menuBar.addmenuitem('Background', 'command', 'Grey',
-                               label='Grey',
-                               command = lambda : cmd.do("_ cmd.bg_color('grey50')"))
-
-
-      self.menuBar.addmenuitem('Background', 'command', 'Black Background',
-                               label='Black',
-                               command = lambda : cmd.do("_ cmd.bg_color('black')"))
-
       self.menuBar.addmenuitem('Display', 'separator', '')
       
       self.menuBar.addmenuitem('Display', 'checkbutton',
@@ -1162,8 +1346,7 @@ class PMGApp(AbstractApp):
                         variable = self.setting.specular,
                         command = lambda s=self: s.setting.update('specular'))
 
-
-      self.menuBar.addmenu('Setting', 'Configuration Control')
+      self.menuBar.addmenu('Setting', 'Configuration Control',tearoff=TRUE)
 
       self.menuBar.addmenuitem('Setting', 'command',
                          'Edit PyMOL Settings',
@@ -1241,11 +1424,11 @@ class PMGApp(AbstractApp):
 
 
       self.menuBar.addmenuitem('Setting', 'command', 'Show Text Output',
-                               label='Show Text',
+                               label=self.pad+'Show Text',
                                command = lambda: cmd.set("text","1",log=1))
 
       self.menuBar.addmenuitem('Setting', 'command', 'Hide Text Output',
-                               label='Hide Text',
+                               label=self.pad+'Hide Text',
                                command = lambda: cmd.set("text","0",log=1))
 
       self.menuBar.addmenuitem('Setting', 'checkbutton',
@@ -1254,9 +1437,49 @@ class PMGApp(AbstractApp):
                         variable = self.setting.overlay,
                         command = lambda s=self: s.setting.update('overlay'))
 
-      
-      self.menuBar.addmenu('Mouse', 'Mouse Configuration')
+      self.menuBar.addmenu('Scene', 'Scene Storage',tearoff=TRUE)
 
+      self.menuBar.addcascademenu('Scene', 'Store', 'Store',
+                                  label=self.pad+'Store')
+
+      self.menuBar.addcascademenu('Scene', 'Clear', 'Clear',
+                                  label=self.pad+'Clear')
+
+      self.menuBar.addmenuitem('Scene', 'separator', '')
+
+      
+      for x in range(1,13):
+         self.menuBar.addmenuitem('Store', 'checkbutton', 'F%d'%x,
+                                  label=self.pad+'F%d'%x,
+                                  variable = self.setting.F[x],
+                                  command = lambda x=x: cmd.do("scene F%d,store"%x))
+
+         self.menuBar.addmenuitem('Clear', 'checkbutton', 'F%d'%x,
+                                  label=self.pad+'F%d'%x,
+                                  variable = self.setting.F[x],
+                                  command = lambda x=x: cmd.do("scene F%d,clear"%x))
+
+         self.menuBar.addmenuitem('Scene', 'checkbutton', 'Recall F%d'%x,
+                                  label=self.pad+'Recall F%d'%x,
+                                  variable = self.setting.F[x],
+                                  command = lambda x=x: cmd.do("scene F%d"%x))
+                      
+      self.menuBar.addmenu('Mouse', 'Mouse Configuration',tearoff=TRUE)
+
+      self.menuBar.addmenuitem('Mouse', 'checkbutton',
+                         'Roving Origin.',
+                         label=self.pad+'Roving Origin',
+                        variable = self.setting.roving_origin,
+                        command = lambda s=self: s.setting.update('roving_origin'))
+
+      self.menuBar.addmenuitem('Mouse', 'checkbutton',
+                         'Roving Detail.',
+                         label=self.pad+'Roving Detail',
+                        variable = self.setting.roving_detail,
+                        command = lambda s=self: s.setting.update('roving_detail'))
+
+      self.menuBar.addmenuitem('Mouse', 'separator', '')
+      
       self.menuBar.addmenuitem('Mouse', 'command', '3 Button Universal Cycle',
                                label='3 Button Universal Cycle',
                                command = lambda: cmd.config_mouse('three_button'))
@@ -1291,7 +1514,7 @@ class PMGApp(AbstractApp):
                                label='2 Button Editing Mode',
                                command = lambda: cmd.mouse('two_button_editing'))
 
-      self.menuBar.addmenu('Cartoon', 'Cartoon Properties')
+      self.menuBar.addmenu('Cartoon', 'Cartoon Properties',tearoff=TRUE)
 
       self.menuBar.addmenuitem('Cartoon', 'checkbutton',
                          'Round Helices',
@@ -1336,8 +1559,14 @@ class PMGApp(AbstractApp):
                         variable = self.setting.cartoon_discrete_colors,
                         command = lambda s=self: s.setting.update('cartoon_discrete_colors'))
 
+      self.menuBar.addmenuitem('Cartoon', 'checkbutton',
+                         'Highlight Color',
+                         label=self.pad+'Highlight Color',
+                        variable = self.setting.cartoon_highlight_color,
+                        command = lambda s=self: s.setting.update('cartoon_highlight_color'))
 
-      self.menuBar.addmenu('Wizard', 'Task Wizards')
+
+      self.menuBar.addmenu('Wizard', 'Task Wizards',tearoff=TRUE)
       
       self.menuBar.addmenuitem('Wizard', 'command', 'Density Map Wizard',
                                label='Density',
@@ -1374,7 +1603,7 @@ class PMGApp(AbstractApp):
                                command = lambda: cmd.do("_ wizard charge"))
 
 
-      self.menuBar.addmenu('Sculpting', 'Sculpting')
+      self.menuBar.addmenu('Sculpting', 'Sculpting',tearoff=TRUE)
 
       self.menuBar.addmenuitem('Sculpting', 'checkbutton',
                          'Auto-Sculpt.',
@@ -1455,38 +1684,69 @@ class PMGApp(AbstractApp):
                                label='All Terms',
                                command = lambda: cmd.do("_ set sculpt_field_mask=127"))
 
-      self.menuBar.addmenu('Demo', 'Demonstrations')
+      self.menuBar.addmenu('Demo', 'Demonstrations',tearoff=TRUE)
 
-      self.demo = Demo()
       
       self.menuBar.addmenuitem('Demo', 'command', 'Representations',
                                label='Representations',
-                               command = lambda s=self:s.demo('rep'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,reps"))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Cartoon Ribbons',
                                label='Cartoon Ribbons',
-                               command = lambda s=self:s.demo('cartoon'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,cartoon"))
+
+      self.menuBar.addmenuitem('Demo', 'command', 'Roving Detail',
+                               label='Roving Detail',
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,roving"))
+      
+      self.menuBar.addmenuitem('Demo', 'command', 'Roving Density',
+                               label='Roving Density',
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,roving_density"))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Transparency',
                                label='Transparency',
-                               command = lambda s=self:s.demo('trans'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,trans"))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Ray Tracing',
                                label='Ray Tracing',
-                               command = lambda s=self:s.demo('ray'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,ray"))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Sculpting',
                                label='Sculpting',
-                               command = lambda s=self:s.demo('sculpt'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,sculpt"))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Scripted Animation',
                                label='Scripted Animation',
-                               command = lambda s=self:s.demo('anime'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,anime"))
+
+
+      self.menuBar.addmenuitem('Demo', 'command', 'Electrostatics',
+                               label='Electrostatics',
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,elec"))
 
-      self.menuBar.addmenuitem('Demo', 'command', 'Molscript/Raster3D Input',
-                               label='Molscript/Raster3D Input',
-                               command = lambda s=self:s.demo('raster3d'))
 
       self.menuBar.addmenuitem('Demo', 'command', 'Compiled Graphics Objects',
                                label='Compiled Graphics Objects',
-                               command = lambda s=self:s.demo('cgo'))
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,cgo"))
+
+      self.menuBar.addmenuitem('Demo', 'command', 'MolScript/Raster3D Input',
+                               label='Molscript/Raster3D Input',
+                               command = lambda: cmd.do(
+         "_ replace_wizard demo,raster3d"))
+
+      self.menuBar.addmenuitem('Demo', 'separator', '')
+      
+      self.menuBar.addmenuitem('Demo', 'command', 'End Demonstration',
+                               label='End Demonstration',
+                               command = lambda s=self:cmd.do(
+         '_ replace_wizard demo,finish'))
