@@ -43,6 +43,22 @@
 #     and should return truth for success or None for failure
 #     (if no exception was raised)
 #
+#
+# NOTE: Output tweaking via the "quiet" parameter of API functions.
+#
+# Many PyMOL API functions have a "quiet" parameter which is used to
+# customize output depending on when and where the routine was called.
+#
+# As defined, quiet should be 1.  Called from an external module, output
+# to the console should be minimal.
+#
+# However, when a command is run through the parser (often manually) the
+# user expects a little more feedback.  The parser will automatically
+# set "quiet" to zero
+#
+# In rare cases, certain nonserious error or warning output should
+# also be suppressed.  Set "quiet" to 2 for this behavior.
+
 
 if __name__=='pymol.cmd':
    
@@ -57,7 +73,8 @@ if __name__=='pymol.cmd':
    import parsing
    import sys
    import __main__
-
+   import time
+   
    from shortcut import Shortcut
 
    from chempy import io
@@ -85,7 +102,8 @@ if __name__=='pymol.cmd':
       r"\.trj$|\.TRJ$|", # AMBER Trajectory
       r"\.crd$|\.CRD$|", # AMBER coordinate file
       r"\.rst$|\.RST$|", # AMBER restart
-      r"\.cex$|\.CEX$", # CEX format (used by metaphorics)
+      r"\.cex$|\.CEX$|", # CEX format (used by metaphorics)
+      r"\.phi$|\.PHI$", # PHI format (delphi)
       ],''))
 
    safe_oname_re = re.compile(r"\ |\+|\(|\)|\||\&|\!|\,")  # quash reserved characters
@@ -99,9 +117,11 @@ if __name__=='pymol.cmd':
    toggle_sc = Shortcut(toggle_dict.keys())
 
    stereo_dict = {'on':1,'off':0,'1':1,'0':0,'swap':-1,
-                  'crosseye':2,'quadbuffer':3} #,'walleye':3}
+                  'crosseye':2,'quadbuffer':3,'walleye':4}
    stereo_sc = Shortcut(stereo_dict.keys())
 
+   space_sc = Shortcut(['cmyk','rgb','pymol'])
+   
    repres = {
       'everything'    : -1,
       'sticks'        : 0,
@@ -123,6 +143,97 @@ if __name__=='pymol.cmd':
    }
    repres_sc = Shortcut(repres.keys())
 
+
+   palette_dict = {
+      'rainbow_cycle'           : ('s',3,0  ,999),
+      'rainbow_cycle_rev'       : ('s',3,999,  0),      
+      'rainbow'                 : ('s',3,167,833),
+      'rainbow_rev'             : ('s',3,833,167),
+
+      'gcbmry' : ('r',3,166,999),
+      'yrmbcg' : ('r',3,999,166),
+      
+      'cbmr'   : ('r',3,166,833),
+      'rmbc'   : ('r',3,833,166),      
+      
+      'green_yellow_red'        : ('s',3,500,833),
+      'red_yellow_green'        : ('s',3,833,500),      
+
+      'yellow_white_blue'       : ('w',3,  0, 83),
+      'blue_white_yellow'       : ('w',3, 83,  0),      
+      
+      'blue_white_red'          : ('w',3, 83,167),
+      'red_white_blue'          : ('w',3,167, 83),
+      
+      'red_white_green'         : ('w',3,167,250),
+      'green_white_red'         : ('w',3,250,167),
+      
+      'green_white_magenta'     : ('w',3,250,333),
+      'magenta_white_green'     : ('w',3,333,250),      
+      
+      'magenta_white_cyan'      : ('w',3,333,417),
+      'cyan_white_magenta'      : ('w',3,417,333),
+      
+      'cyan_white_yellow'       : ('w',3,417,500),
+      'yellow_cyan_white'       : ('w',3,500,417),
+      
+      'yellow_white_green'      : ('w',3,500,583),
+      'green_white_yellow'      : ('w',3,583,500),
+      
+      'green_white_blue'        : ('w',3,583,667),
+      'blue_white_green'        : ('w',3,667,583),      
+      
+      'blue_white_magenta'      : ('w',3,667,750),
+      'magenta_white_blue'      : ('w',3,750,667),
+      
+      'magenta_white_yellow'    : ('w',3,750,833),
+      'yellow_white_magenta'    : ('w',3,833,750),
+      
+      'yellow_white_red'        : ('w',3,833,917),
+      'red_white_yellow'        : ('w',3,817,833),
+      
+      'red_white_cyan'          : ('w',3,916,999),
+      'cyan_white_red'          : ('w',3,999,916),      
+
+      'yellow_blue'       : ('w',3,  0, 83),
+      'blue_yellow'       : ('w',3, 83,  0),      
+      
+      'blue_red'          : ('w',3, 83,167),
+      'red_blue'          : ('w',3,167, 83),
+      
+      'red_green'         : ('w',3,167,250),
+      'green_red'         : ('w',3,250,167),
+      
+      'green_magenta'     : ('w',3,250,333),
+      'magenta_green'     : ('w',3,333,250),      
+      
+      'magenta_cyan'      : ('w',3,333,417),
+      'cyan_magenta'      : ('w',3,417,333),
+      
+      'cyan_yellow'       : ('w',3,417,500),
+      'yellow_cyan'       : ('w',3,500,417),
+      
+      'yellow_green'      : ('w',3,500,583),
+      'green_yellow'      : ('w',3,583,500),
+      
+      'green_blue'        : ('w',3,583,667),
+      'blue_green'        : ('w',3,667,583),      
+      
+      'blue_magenta'      : ('w',3,667,750),
+      'magenta_blue'      : ('w',3,750,667),
+      
+      'magenta_yellow'    : ('w',3,750,833),
+      'yellow_magenta'    : ('w',3,833,750),
+      
+      'yellow_red'        : ('w',3,833,917),
+      'red_yellow'        : ('w',3,817,833),
+      
+      'red_cyan'          : ('w',3,916,999),
+      'cyan_red'          : ('w',3,999,916),      
+      }
+
+   palette_sc = Shortcut(palette_dict.keys())
+   
    def null_function():
       pass
 
@@ -135,6 +246,9 @@ if __name__=='pymol.cmd':
    def is_list(obj):
       return isinstance(obj,types.ListType)
 
+   def is_tuple(obj):
+      return isinstance(obj,types.TupleType)
+
    #--------------------------------------------------------------------
    # locks and threading
 
@@ -151,28 +265,49 @@ if __name__=='pymol.cmd':
       lock_api_c.release()
 
    def lock(): # INTERNAL
-      lock_api.acquire(1) 
-
+#      print " lock: acquiring as 0x%x"%thread.get_ident(),(thread.get_ident() == pymol.glutThread)
+      if not lock_api.acquire(0):
+         w = 0.001
+         while 1:
+#            print " lock: ... as 0x%x"%thread.get_ident(),(thread.get_ident() == pymol.glutThread)
+            e = threading.Event() 
+            e.wait(w)  
+            del e
+            if lock_api.acquire(0):
+               break
+            if w<0.1:
+               w = w * 2 # wait twice as long each time until flushed
+#      print "lock: acquired by 0x%x"%thread.get_ident()
+      
    def lock_attempt(): # INTERNAL
-      return lock_api.acquire(blocking=0)
+#       print " lock: attempting as 0x%x"%thread.get_ident(),(thread.get_ident() == pymol.glutThread)
+       result = lock_api.acquire(blocking=0)
+#       if result:
+#          print "lock: acquired by 0x%x"%thread.get_ident()
+       return result
 
    def unlock(): # INTERNAL
       if (thread.get_ident() == pymol.glutThread):
          lock_api.release()
+#         print "lock: released by 0x%x (glut)"%thread.get_ident()
          _cmd.flush_now()
       else:
+#         print "lock: released by 0x%x (not glut), waiting queue"%thread.get_ident()
          lock_api.release()
          if _cmd.wait_queue(): # commands waiting to be executed?
-            w = 0.0025 # NOTE: affects API perf. for "do" and delayed-exec
-            while 1:
-               e = threading.Event() # using this for portable delay
+            e = threading.Event() # abdicate control for a 100 usec for quick tasks
+            e.wait(0.0001)
+            del e
+            # then give PyMOL increasingly longer intervals to get its work done...
+            w = 0.0005  # NOTE: affects API perf. for "do" and delayed-exec
+            while _cmd.wait_queue(): 
+               e = threading.Event() # abdicate control for a 100 usec for quick tasks
                e.wait(w)
                del e
-               if not _cmd.wait_queue():
-                  break
                if w > 0.1: # wait up 0.2 sec max for PyMOL to flush queue
                   if _feedback(fb_module.cmd,fb_mask.debugging):
                      fb_debug.write("Debug: avoiding possible dead-lock?\n")
+#                  print "dead locked as 0x%x"%thread.get_ident()
                   break
                w = w * 2 # wait twice as long each time until flushed
 
@@ -208,6 +343,7 @@ if __name__=='pymol.cmd':
       raw                       =7
       isosurface                =8
 
+      cgo                       =11
       feedback                  =12
       scene                     =13
       threads                   =14  
@@ -224,7 +360,8 @@ if __name__=='pymol.cmd':
 
       coordset                  =25
       distset                   =26
-
+      gadgetset                 =27
+      
       objectmolecule            =30
       objectmap                 =31
       objectmesh                =32
@@ -232,7 +369,8 @@ if __name__=='pymol.cmd':
       objectcgo                 =34
       objectcallback            =35
       objectsurface             =36
-
+      objectgadget              =37
+      
       repwirebond               =45
       repcylbond                =46
       replabel                  =47
@@ -247,7 +385,8 @@ if __name__=='pymol.cmd':
       repribbon                 =57
       repcartoon                =58
       sculpt                    =59
-
+      vfont                     =60
+      
       executive                 =70
       selector                  =71
       editor                    =72
@@ -267,12 +406,13 @@ if __name__=='pymol.cmd':
    fb_module_sc = Shortcut(fb_module.__dict__.keys())
 
    class fb_mask:
-      results =             0x01
-      errors =              0x02
-      actions =             0x04
-      warnings =            0x08
-      details =             0x10
-      blather =             0x20
+      output =              0x01 # Python/text output
+      results =             0x02
+      errors =              0x04
+      actions =             0x08
+      warnings =            0x10
+      details =             0x20
+      blather =             0x40
       debugging =           0x80
       everything =          0xFF
 
@@ -443,7 +583,7 @@ if __name__=='pymol.cmd':
             fname = re.sub("\.png$","",fname)
          fname = os.path.expanduser(fname)
          fname = os.path.expandvars(fname)
-         r = _cmd.mpng_(str(fname),arg[1],arg[2])
+         r = _cmd.mpng_(str(fname),int(arg[1]),int(arg[2]))
       finally:
          unlock()
       return r
@@ -496,6 +636,12 @@ if __name__=='pymol.cmd':
       if special.has_key(k):
          if special[k][1]:
             apply(special[k][1],special[k][2],special[k][3])
+         else:
+            key = special[k][0]
+            if viewing.scene_dict.has_key(key):
+               scene(key)
+            elif viewing.view_dict.has_key(key):
+               view(key)
       return None
 
    # control keys
@@ -553,18 +699,20 @@ if __name__=='pymol.cmd':
                r = _cmd.refresh()
          else:
             print "Error: Ignoring an unsafe call to cmd._refresh"
-      finally:      unlock()
+      finally:
+         unlock()
       return r
 
    # stereo (platform dependent )
 
    def _sgi_stereo(flag): # SGI-SPECIFIC - bad bad bad
 
-      if os.path.exists("/usr/gfx/setmon"):
-         if flag:
-            os.system("/usr/gfx/setmon -n 1024x768_96s")
-         else:
-            os.system("/usr/gfx/setmon -n 72hz")
+      if sys.platform[0:4]=='irix':
+         if os.path.exists("/usr/gfx/setmon"):
+            if flag:
+               os.system("/usr/gfx/setmon -n 1024x768_96s")
+            else:
+               os.system("/usr/gfx/setmon -n 72hz")
 
    # color alias interpretation
 
@@ -624,6 +772,17 @@ if __name__=='pymol.cmd':
       if c!=cnt:
          print
 
+   def _dump_ufloats(lst,format="%7.3f",cnt=9):
+      c = cnt
+      for a in lst:
+         print format%abs(a),
+         c = c -1
+         if c<=0:
+            print
+            c=cnt
+      if c!=cnt:
+         print
+
    # HUH?
    def _adjust_coord(a,i,x):
       a.coord[i]=a.coord[i]+x
@@ -779,6 +938,7 @@ if __name__=='pymol.cmd':
         load,               \
         load_brick,         \
         load_callback,      \
+        space,       \
         load_cgo,           \
         load_map,           \
         load_model,         \
@@ -787,6 +947,7 @@ if __name__=='pymol.cmd':
         read_mmodstr,       \
         read_molstr,        \
         read_pdbstr,        \
+        read_xplorstr,      \
         loadable,           \
         set_session
 
@@ -797,10 +958,12 @@ if __name__=='pymol.cmd':
         create,             \
         fragment,           \
         isodot,             \
+        isolevel,           \
         isomesh,            \
         isosurface,         \
         symexp,             \
-        map_new
+        map_new,            \
+        ramp_new
 
    #--------------------------------------------------------------------
    from commanding import \
@@ -813,6 +976,7 @@ if __name__=='pymol.cmd':
         quit,               \
         resume,             \
         splash,             \
+        reinitialize,       \
         sync
 
    #--------------------------------------------------------------------
@@ -836,11 +1000,13 @@ if __name__=='pymol.cmd':
         export_dots,        \
         find_pairs,         \
         get_area,           \
+        get_chains,         \
         get_color_indices,  \
         get_color_tuple,    \
         get_dihedral,       \
         get_extent,         \
         get_model,          \
+        get_movie_locked,   \
         get_names,          \
         get_names_of_type,  \
         get_phipsi,         \
@@ -927,8 +1093,11 @@ if __name__=='pymol.cmd':
    #--------------------------------------------------------------------
    from wizarding import \
         get_wizard,         \
+        get_wizard_stack,   \
         refresh_wizard,     \
+        replace_wizard,     \
         set_wizard,         \
+        set_wizard_stack,   \
         wizard
 
    #--------------------------------------------------------------------
@@ -973,11 +1142,15 @@ if __name__=='pymol.cmd':
         cartoon,            \
         clip,               \
         color,              \
+        del_colorection,    \
         dirty,              \
         disable,            \
         enable,             \
         full_screen,        \
+        get_colorection,    \
         get_view,           \
+        get_vis,            \
+        get_scene_dict,     \
         hide,               \
         label,              \
         load_png,           \
@@ -992,9 +1165,13 @@ if __name__=='pymol.cmd':
         refresh,            \
         reset,              \
         rock,               \
+        scene,              \
         set_color,          \
+        set_colorection,    \
+        set_vis,            \
         set_view,           \
         show,               \
+        spectrum,           \
         stereo,             \
         turn,               \
         view,               \
@@ -1005,6 +1182,7 @@ if __name__=='pymol.cmd':
    import setting
    from setting import \
         set,                 \
+        get,                 \
         unset,               \
         get_setting_legacy,  \
         get_setting_tuple,   \
@@ -1089,7 +1267,7 @@ if __name__=='pymol.cmd':
       'del'           : [ dummy_python      , 0 , 0 , ''  , parsing.PYTHON ],
       'deprotect'     : [ deprotect         , 0 , 0 , ''  , parsing.STRICT ],
       'deselect'      : [ deselect          , 0 , 0 , ''  , parsing.STRICT ],
-      'dir'           : [ ls                , 0 , 0 , ''  , parsing.STRICT ],  
+      'dir'           : [ ls                , 0 , 0 , ''  , parsing.STRICT ],
       'disable'       : [ disable           , 0 , 0 , ''  , parsing.STRICT ],
       'distance'      : [ distance          , 0 , 0 , ''  , parsing.LEGACY ],   
       'dump'          : [ dump              , 0 , 0 , ''  , parsing.STRICT ],
@@ -1116,7 +1294,9 @@ if __name__=='pymol.cmd':
       'full_screen'   : [ full_screen       , 0 , 0 , ''  , parsing.STRICT ],
       'fuse'          : [ fuse              , 0 , 0 , ''  , parsing.STRICT ],
       'frame'         : [ frame             , 0 , 0 , ''  , parsing.STRICT ],
+      'get'           : [ get               , 0 , 0 , ''  , parsing.STRICT ],      
       'get_area'      : [ get_area          , 0 , 0 , ''  , parsing.STRICT ],
+      'get_chains'    : [ get_chains        , 0 , 0 , ''  , parsing.STRICT ],
       'get_dihedral'  : [ get_dihedral      , 0 , 0 , ''  , parsing.STRICT ],
       'get_extent'    : [ get_extent        , 0 , 0 , ''  , parsing.STRICT ],   
       'get_position'  : [ get_position      , 0 , 0 , ''  , parsing.STRICT ],
@@ -1138,13 +1318,15 @@ if __name__=='pymol.cmd':
       'intra_rms'     : [ intra_rms         , 0 , 0 , ''  , parsing.STRICT ],
       'intra_rms_cur' : [ intra_rms_cur     , 0 , 0 , ''  , parsing.STRICT ],
       'invert'        : [ invert            , 0 , 0 , ''  , parsing.STRICT ],
-      'isodot'        : [ isodot            , 0 , 0 , ''  , parsing.LEGACY ],   
+      'isodot'        : [ isodot            , 0 , 0 , ''  , parsing.LEGACY ],
+      'isolevel'      : [ isolevel           , 0 , 0 , '' , parsing.STRICT ],      
       'isomesh'       : [ isomesh           , 0 , 0 , ''  , parsing.LEGACY ],
       'isosurface'    : [ isosurface        , 0 , 0 , ''  , parsing.LEGACY ],   
       'iterate'       : [ iterate           , 0 , 0 , ''  , parsing.LITERAL1 ],
       'iterate_state' : [ iterate_state     , 0 , 0 , ''  , parsing.LITERAL2 ],
       'label'         : [ label             , 0 , 0 , ''  , parsing.LITERAL1 ],
       'load'          : [ load              , 0 , 0 , ''  , parsing.STRICT ],
+      'space'         : [ space             , 0 , 0 , ''  , parsing.STRICT ],      
       'load_png'      : [ load_png          , 0 , 0 , ''  , parsing.STRICT ],
       'load_traj'     : [ load_traj         , 0 , 0 , ''  , parsing.STRICT ],
       'log'           : [ log               , 0 , 0 , ''  , parsing.STRICT ],
@@ -1181,15 +1363,19 @@ if __name__=='pymol.cmd':
       'push_undo'     : [ push_undo         , 0 , 0 , ''  , parsing.STRICT ],   
       'pwd'           : [ pwd               , 0 , 0 , ''  , parsing.STRICT ],
       'raise'         : [ dummy_python      , 0 , 0 , ''  , parsing.PYTHON ],
+      'ramp_new'      : [ ramp_new          , 0 , 0 , ''  , parsing.STRICT ],      
       'ray'           : [ ray               , 0 , 0 , ''  , parsing.STRICT ],
       'rebuild'       : [ rebuild           , 0 , 0 , ''  , parsing.STRICT ],
       'recolor'       : [ recolor           , 0 , 0 , ''  , parsing.STRICT ],   
       'redo'          : [ redo              , 0 , 0 , ''  , parsing.STRICT ],
+      'reinitialize'  : [ reinitialize      , 0 , 0 , ''  , parsing.STRICT ],      
       'refresh'       : [ refresh           , 0 , 0 , ''  , parsing.STRICT ],
+      'refresh_wizard' : [ refresh_wizard   , 0 , 0 , ''  , parsing.STRICT ],
       'remove'        : [ remove            , 0 , 0 , ''  , parsing.STRICT ],
       'remove_picked' : [ remove_picked     , 0 , 0 , ''  , parsing.STRICT ],
       'rename'        : [ rename            , 0 , 0 , ''  , parsing.STRICT ],
       'replace'       : [ replace           , 0 , 0 , ''  , parsing.STRICT ],
+      'replace_wizard': [ replace_wizard    , 0 , 0 , ''  , parsing.STRICT ],
       'reset'         : [ reset             , 0 , 0 , ''  , parsing.STRICT ],
       'resume'        : [ resume            , 0 , 0 , ''  , parsing.STRICT ],
       'return'        : [ dummy_python      , 0 , 0 , ''  , parsing.PYTHON ],   
@@ -1200,10 +1386,12 @@ if __name__=='pymol.cmd':
       'rms'           : [ rms               , 0 , 0 , ''  , parsing.STRICT ],
       'rms_cur'       : [ rms_cur           , 0 , 0 , ''  , parsing.STRICT ],
       'save'          : [ save              , 0 , 0 , ''  , parsing.STRICT ],
+      'scene'         : [ scene             , 0 , 0 , ''  , parsing.STRICT ],
       'sculpt_purge'  : [ sculpt_purge      , 0 , 0 , ''  , parsing.STRICT ],   
       'sculpt_deactivate': [ sculpt_deactivate , 0 , 0 , ''  , parsing.STRICT ],
       'sculpt_activate': [ sculpt_activate  , 0 , 0 , ''  , parsing.STRICT ],
       'sculpt_iterate': [ sculpt_iterate    , 0 , 0 , ''  , parsing.STRICT ],
+      'spectrum'      : [ spectrum          , 0 , 0 , ''  , parsing.STRICT ],
       'select'        : [ select            , 0 , 0 , ''  , parsing.LEGACY ],
       'set'           : [ set               , 0 , 0 , ''  , parsing.LEGACY ],
       'set_color'     : [ set_color         , 0 , 0 , ''  , parsing.LEGACY ],
@@ -1310,8 +1498,8 @@ if __name__=='pymol.cmd':
       8        : [ 'F8'        , None                   , () , {} ],
       9        : [ 'F9'        , None                   , () , {} ],
       10       : [ 'F10'       , None                   , () , {} ],
-      11       : [ 'F11'       , redo                   , () , {} ],
-      12       : [ 'F12'       , undo                   , () , {} ],
+      11       : [ 'F11'       , None                   , () , {} ],
+      12       : [ 'F12'       , None                   , () , {} ],
       100      : [ 'left'      , backward               , () , {} ],
       101      : [ 'up'        , None                   , () , {} ],
       102      : [ 'right'     , forward                , () , {} ],
@@ -1397,9 +1585,12 @@ if __name__=='pymol.cmd':
 
    auto_arg =[
       {
+      'bg'             : [ _get_color_sc          , 'color'           , ''   ],      
       'color'          : [ _get_color_sc          , 'color'           , ', ' ],
-      'cartoon'        : [ viewing.cartoon_sc     , 'cartoon'         , ', ' ],      
+      'cartoon'        : [ viewing.cartoon_sc     , 'cartoon'         , ', ' ],
+      'space'          : [ space_sc               , 'space'           , ''   ],      
       'set'            : [ setting.setting_sc     , 'setting'         , ','  ],
+      'get'            : [ setting.setting_sc     , 'setting'         , ','  ],      
       'flag'           : [ editing.flag_sc        , 'flag'            , ', ' ],
       'show'           : [ repres_sc              , 'representation'  , ', ' ],
       'hide'           : [ repres_sc              , 'representation'  , ', ' ],
@@ -1422,7 +1613,9 @@ if __name__=='pymol.cmd':
       'iterate_state'  : [ selection_sc           , 'selection'       , ''   ],
       'smooth'         : [ selection_sc           , 'selection'       , ''   ],
       'help'           : [ help_sc                , 'selection'       , ''   ],
-      'unset'          : [ setting.setting_sc     , 'setting'         , ','  ],   
+      'unset'          : [ setting.setting_sc     , 'setting'         , ','  ],
+      'view'           : [ viewing.view_dict_sc   , 'view'            , ''   ],                              
+      'scene'          : [ viewing.scene_dict_sc  , 'scene'           , ''   ],                        
       },
       {
       'align'          : [ selection_sc           , 'selection'       , ''   ],
@@ -1438,12 +1631,16 @@ if __name__=='pymol.cmd':
       'load_traj'      : [ selection_sc           , 'selection'       , ', ' ],
       'create'         : [ selection_sc           , 'selection'       , ', ' ],
       'map_new'        : [ creating.map_type_sc   , 'map type'        , ', ' ],
+      'spectrum'       : [ palette_sc             , 'palette'         , ''   ],      
+
       'symexp'         : [ object_sc              , 'object'          , ', ' ],   
       'isomesh'        : [ map_sc                 , 'map object'      , ', ' ],
-      'view'           : [ viewing.view_sc        , 'view action'     , ''   ],            
-      'unset'          : [ selection_sc           , 'selection'         , ','  ],   
+      'view'           : [ viewing.view_sc        , 'view action'     , ''   ],
+      'scene'          : [ viewing.view_sc        , 'scene action'    , ','   ],                  
+      'unset'          : [ selection_sc           , 'selection'        , ','  ],   
       },
       {
+      'spectrum'       : [ selection_sc           , 'selection'       , ''   ],
       'feedback'       : [ fb_mask_sc             , 'mask'            , ''   ],
       'button'         : [ controlling.but_act_sc , 'button action'   , ''   ],
       'flag'           : [ editing.flag_action_sc , 'flag action'     , ''   ],
