@@ -58,10 +58,11 @@ if __name__=='pymol.controlling':
       '-lbx' : 20 ,
       'lbbx' : 21 ,
       'none' : 22 ,
+      'cent' : 23 ,
+      'pktb' : 24 ,
       }
    but_act_sc = Shortcut(but_act_code.keys())
 
-
    ring_dict = {
       'three_button' : [   'three_button_viewing',
                            'three_button_editing' ],
@@ -98,7 +99,7 @@ if __name__=='pymol.controlling':
                                  ('m','ctrl','pkat'),
                                  ('r','ctrl','pkbd'),                 
                                  ('l','ctsh','lb'),
-                                 ('m','ctsh','orig'),
+                                 ('m','ctsh','cent'),
                                  ('r','ctsh','rb')
                                  ],
 
@@ -110,9 +111,9 @@ if __name__=='pymol.controlling':
                                 ('r','shft','clip') ,                 
                                 ('l','ctrl','torf'),
                                 ('m','ctrl','pkat'),
-                                ('r','ctrl','pkbd'),                  
+                                ('r','ctrl','pktb'),                  
                                 ('l','ctsh','lb'),
-                                ('m','ctsh','orig'),
+                                ('m','ctsh','cent'),
                                 ('r','ctsh','rb'),
                                 ],
 
@@ -127,7 +128,7 @@ if __name__=='pymol.controlling':
                                ('r','ctrl','pkbd'),                 
                                ('l','ctsh','lb'),
                                ('m','ctsh','none'),
-                               ('r','ctsh','orig')
+                               ('r','ctsh','cent')
                                ],
       'two_button_selecting' : [ ('l','none','rota'),
                                  ('m','none','none'),
@@ -150,7 +151,7 @@ if __name__=='pymol.controlling':
                                ('r','shft','clip'),                 
                                ('l','ctrl','torf'),
                                ('m','ctrl','none'),
-                               ('r','ctrl','pkbd'),                 
+                               ('r','ctrl','pktb'),                 
                                ('l','ctsh','rotf'),
                                ('m','ctsh','none'),
                                ('r','ctsh','movf')
@@ -308,7 +309,7 @@ NOTES
    modifers:    None, Shft, Ctrl, CtSh
    actions:     Rota, Move, MovZ, Clip, RotZ, ClpN, ClpF
                 lb,   mb,   rb,   +lb,  +lbX, -lbX, +mb,  +rb, 
-                PkAt, PkBd, RotF, TorF, MovF, Orig
+                PkAt, PkBd, RotF, TorF, MovF, Orig, Cent
 
    '''
       r=1
