@@ -21,7 +21,7 @@ if __name__=='pymol.importing':
    from cmd import _cmd,lock,unlock,Shortcut,QuietException, \
         _feedback,fb_module,fb_mask, \
         file_ext_re,safe_oname_re, \
-        _load, is_list
+        _load, is_list, space_sc
    import selector
    try:
       from pymol import m4x
@@ -31,7 +31,7 @@ if __name__=='pymol.importing':
    from chempy.sdf import SDF,SDFRec
    from chempy import io
    import pymol
-
+   
    class loadable:
       pdb = 0
       mol = 1
@@ -56,7 +56,9 @@ if __name__=='pymol.importing':
       crd = 23      # AMBER coordinate
       rst = 24      # AMBER restart
       pse = 25      # PyMOL session
-
+      xplorstr = 26 # XPLOR map as string
+      phi = 27      # Delphi/Grasp
+      
    loadable_sc = Shortcut(loadable.__dict__.keys()) 
 
    def set_session(session):
@@ -72,6 +74,8 @@ if __name__=='pymol.importing':
          else:
             r = apply(a,(session,))
          if not r: break
+      if cmd.get_movie_locked():
+         cmd.wizard("security")
       return r
 
    def load_object(type,object,name,state=0,finish=1,discrete=0):
@@ -114,6 +118,34 @@ PYMOL API
       lst.extend(list(arg))
       return apply(load_object,lst)
 
+   def space(space="",quiet=0):
+      r=None
+      
+      tables = { 'cmyk' : "$PYMOL_PATH/data/pymol/cmyk.png",
+                 'pymol' : 'pymol',
+                 'rgb' : 'rgb' }
+
+      space_auto = space_sc.interpret(space)
+      if (space_auto != None) and not is_list(space_auto):
+         space = space_auto
+         
+      if space=="": 
+         filename = ""
+      else:         
+         filename = tables.get(string.lower(space),"")
+         if filename == "":
+            print "Error: unknown color space '%s'\n"%space
+            raise QuietException
+      try:
+         filename = os.path.expanduser(filename)
+         filename = os.path.expandvars(filename)
+
+         lock()
+         r = _cmd.load_color_table(str(filename),int(quiet))
+      finally:
+         unlock()
+      return r
+
    def load_callback(*arg):
       '''
 DESCRIPTION
@@ -363,6 +395,8 @@ SEE ALSO
                ftype = loadable.crd
             elif re.search("\.pse$",filename,re.I):
                ftype = loadable.pse
+            elif re.search("\.phi$",filename,re.I):
+               ftype = loadable.phi
             else:
                ftype = loadable.pdb # default is PDB
          elif cmd.is_string(type):
@@ -520,6 +554,35 @@ NOTES
          unlock()
       return r
 
+   def read_xplorstr(xplor,name,state=0,finish=1,discrete=0):
+      '''
+DESCRIPTION
+
+   "read_xplorstr" in an API-only function which reads an XPLOR map
+   from a Python string.  This feature can be used to bypass
+   temporary files.
+
+PYMOL API ONLY
+
+   cmd.read_xplorstr( string xplor-content, string object name 
+      [ ,int state ] )
+
+NOTES
+
+   "state" is a 1-based state index for the object.
+
+   '''
+      r = 1
+      try:
+         lock()   
+         ftype = loadable.xplorstr
+         oname = string.strip(str(name))
+         r = _cmd.load(str(oname),xplor,int(state)-1,int(ftype),
+                          int(finish),int(discrete))
+      finally:
+         unlock()
+      return r
+
    def finish_object(name):
       '''
 DESCRIPTION
