@@ -40,6 +40,8 @@ def mol_show(s):
 
 def mol_hide(s):
    return [[ 2, 'Hide:'     , ''                                ],
+           [ 1, 'everything', 'cmd.hide("everything","'+s+'")'  ],
+           [ 0, ''          , ''                                ],
            [ 1, 'lines'     , 'cmd.hide("lines"     ,"'+s+'")'  ],
            [ 1, 'nonbonded' , 'cmd.hide("nonbonded" ,"'+s+'")'  ],           
            [ 1, 'sticks'    , 'cmd.hide("sticks"    ,"'+s+'")'  ],
@@ -60,7 +62,6 @@ def mol_hide(s):
            [ 1, 'side chain', 'cmd.hide("((byres ('+s+'))&!n;ca,c,n,o,h)")' ],
            [ 0, ''          , ''                                ],
            [ 1, 'hydrogens' , 'cmd.hide("('+s+' and hydro)")'   ],
-           [ 1, 'everything', 'cmd.hide("everything","'+s+'")'  ],
            [ 0, ''          , ''                                ],           
            [ 1, 'unselected', 'cmd.hide("(not '+s+')")'         ],
            ]
@@ -89,11 +90,11 @@ def cgo_hide(s):
 
 def simple_show(s):
    return [[ 2, 'Show:'       , ''                             ],
-           [ 1, 'everything'  , 'cmd.enable("'+s+'")'          ]]
+           [ 1, 'everything'  , 'cmd.show("everything","'+s+'")'          ]]
 
 def simple_hide(s):
    return [[ 2, 'Hide:'     ,''                                ],
-           [ 1, 'everything'    ,'cmd.disable("'+s+'")'        ]]
+           [ 1, 'everything'    ,'cmd.hide("everything","'+s+'")'        ]]
 
 def mesh_show(s):
    return [[ 2, 'Show:'       , ''                             ],
@@ -109,39 +110,51 @@ def mesh_hide(s):
 
 def mol_color(s):
    return [[ 2, 'Color:'     ,''                               ],
-           [ 1, '`292C`777H`229N`922O`950S`905*'  , 'util.cbag("'+s+'")'],
-           [ 1, '`099C`777H`229N`922O`950S`905*'  , 'util.cbac("'+s+'")'],
-           [ 1, '`990C`777H`229N`922O`950S`905*'  , 'util.cbay("'+s+'")'],
-           [ 1, '`955C`777H`229N`922O`950S`905*'  , 'util.cbas("'+s+'")'],
-           [ 1, '`777C`777H`229N`922O`950S`905*'  , 'util.cbaw("'+s+'")'],
-           [ 1, '`559C`777H`229N`922O`950S`905*'  , 'util.cbab("'+s+'")'],
+           [ 1, 'elems `292C`777H`229N`922O`950S`905*'  , 'util.cbag("'+s+'")'],
+           [ 1, 'elems `099C`777H`229N`922O`950S`905*'  , 'util.cbac("'+s+'")'],
+           [ 1, 'elems `909C`777H`229N`922O`950S`905*'  , 'util.cbam("'+s+'")'],           
+           [ 1, 'elems `990C`777H`229N`922O`950S`905*'  , 'util.cbay("'+s+'")'],
+           [ 1, 'elems `955C`777H`229N`922O`950S`905*'  , 'util.cbas("'+s+'")'],
+           [ 1, 'elems `777C`777H`229N`922O`950S`905*'  , 'util.cbaw("'+s+'")'],
+           [ 1, 'elems `559C`777H`229N`922O`950S`905*'  , 'util.cbab("'+s+'")'],
+           [ 1, 'elems `972C`777H`229N`922O`950S`905*'  , 'util.cbao("'+s+'")'],
+           [ 1, 'elems  `777H`229N`922O`950S`905*'  , 'util.cnc("'+s+'")'],                      
            [ 0, ''                                , ''                 ],
-           [ 1, '`900r`950a`990i`090n`099b`059o`009w', 'util.rainbow("'+s+'")'],
-           [ 1, '`900r`950a`990i`090n`099b`059o`009w`999(*/ca)', 'util.rainbow("('+s+')&*/ca")'],
-           [ 1, '`900b`950y `990c`090h`099a`059i`009n', 'util.color_chains("('+s+')")'],                      
+           [ 1, '`900r`950a`990i`090n`099b`059o`009w`888(e. c)',
+             'cmd.spectrum("count",selection="('+s+')&e. c")'],           
+           [ 1, '`900r`950a`990i`090n`099b`059o`009w`888(*/ca)',
+             'cmd.spectrum("count",selection="('+s+')&*/ca")'],
+           [ 1, '`900r`950a`990i`090n`099b`059o`009w',
+             'cmd.spectrum("count",selection="'+s+'",byres=1)'],
+           [ 1, '`900c`950h`990a`090i`099n`059b`009o`705w`888s',
+             'util.chainbow("('+s+')")'],                                 
+           [ 1, '`900b`950y `090c`099h`059a`009i`705n',
+             'util.color_chains("('+s+')")'],
            [ 0, ''                                , ''                 ],           
            [ 1, '`900red'         , 'cmd.color("red","'+s+'")'     ],
            [ 1, '`090green'       , 'cmd.color("green","'+s+'")'   ],
            [ 1, '`009blue'        , 'cmd.color("blue","'+s+'")'    ],
            [ 1, '`990yellow'      , 'cmd.color("yellow","'+s+'")'  ],
-           [ 1, '`909violet'      , 'cmd.color("violet","'+s+'")'  ],
+           [ 1, '`909magenta'     , 'cmd.color("magenta","'+s+'")' ],
            [ 1, '`099cyan'        , 'cmd.color("cyan","'+s+'")'    ],           
            [ 1, '`955salmon'      , 'cmd.color("salmon","'+s+'")'  ],
            [ 1, '`595lime'        , 'cmd.color("lime","'+s+'")'    ],
-           [ 1, '`968pink'  ,'cmd.color("pink","'+s+'")'  ],
+           [ 1, '`967pink'  ,'cmd.color("pink","'+s+'")'  ],
            [ 1, '`559slate'       , 'cmd.color("slate","'+s+'")'   ],
-           [ 1, '`905magenta'     , 'cmd.color("magenta","'+s+'")' ],
+           [ 1, '`949violet'      , 'cmd.color("violet","'+s+'")'  ],
            [ 1, '`950orange'      , 'cmd.color("orange","'+s+'")'  ],
            [ 1, '`059marine'      , 'cmd.color("marine","'+s+'")'  ],
-           [ 1, '`551olive'       , 'cmd.color("olive","'+s+'")'   ],
-           [ 1, '`626purple'      , 'cmd.color("purple","'+s+'")'  ],
-           [ 1, '`266teal'        , 'cmd.color("teal","'+s+'")'    ],
-           [ 1, '`151forest'      , 'cmd.color("forest","'+s+'")'  ],
-           [ 1, '`611firebrick'   , 'cmd.color("firebrick","'+s+'")'  ],
-           [ 1, '`631chocolate'   , 'cmd.color("chocolate","'+s+'")'  ],           
+           [ 1, '`905hotpink' ,'cmd.color("hotpink","'+s+'")'  ],
+#           [ 1, '`551olive'       , 'cmd.color("olive","'+s+'")'   ],
+#           [ 1, '`626purple'      , 'cmd.color("purple","'+s+'")'  ],
+#           [ 1, '`266teal'        , 'cmd.color("teal","'+s+'")'    ],
+#           [ 1, '`151forest'      , 'cmd.color("forest","'+s+'")'  ],
+#           [ 1, '`611firebrick'   , 'cmd.color("firebrick","'+s+'")'  ],
+#           [ 1, '`631chocolate'   , 'cmd.color("chocolate","'+s+'")'  ],           
            [ 1, '`999white'       , 'cmd.color("white","'+s+'")'   ],
            [ 1, '`987wheat'       , 'cmd.color("wheat","'+s+'")'   ],
-           [ 1, '`555grey'        , 'cmd.color("grey","'+s+'")'    ]
+           [ 1, '`555grey'        , 'cmd.color("grey","'+s+'")'    ],
+           [ 1, '`222black'    ,'cmd.color("grey","'+s+'")'  ]
            ]
 
 def general_color(s):
@@ -150,36 +163,44 @@ def general_color(s):
            [ 1, '`090green'       ,'cmd.color("green","'+s+'")'  ],
            [ 1, '`009blue'        ,'cmd.color("blue","'+s+'")'  ],
            [ 1, '`990yellow'      ,'cmd.color("yellow","'+s+'")'  ],
-           [ 1, '`909violet'  ,'cmd.color("violet","'+s+'")'  ],
+           [ 1, '`909magenta' ,'cmd.color("magenta","'+s+'")'  ],
            [ 1, '`099cyan'  ,'cmd.color("cyan","'+s+'")'  ],           
            [ 1, '`955salmon'      ,'cmd.color("salmon","'+s+'")'  ],
            [ 1, '`595lime' ,'cmd.color("lime","'+s+'")'  ],
            [ 1, '`967pink'  ,'cmd.color("pink","'+s+'")'  ],
            [ 1, '`559slate'  ,'cmd.color("slate","'+s+'")'  ],
-           [ 1, '`905magenta' ,'cmd.color("magenta","'+s+'")'  ],
+           [ 1, '`949violet'  ,'cmd.color("violet","'+s+'")'  ],
            [ 1, '`950orange'      ,'cmd.color("orange","'+s+'")'  ],
            [ 1, '`059marine'      ,'cmd.color("marine","'+s+'")'  ],
-           [ 1, '`551olive'   ,'cmd.color("olive","'+s+'")'  ],
-           [ 1, '`626purple'  ,'cmd.color("purple","'+s+'")'  ],
-           [ 1, '`266teal'  ,'cmd.color("teal","'+s+'")'  ],
-           [ 1, '`151forest'  ,'cmd.color("forest","'+s+'")'  ],
-           [ 1, '`611firebrick'   , 'cmd.color("firebrick","'+s+'")'  ],
-           [ 1, '`631chocolate'   , 'cmd.color("chocolate","'+s+'")'  ],           
+           [ 1, '`905hotpink' ,'cmd.color("hotpink","'+s+'")'  ],
+#           [ 1, '`551olive'   ,'cmd.color("olive","'+s+'")'  ],
+#           [ 1, '`626purple'  ,'cmd.color("purple","'+s+'")'  ],
+#           [ 1, '`266teal'  ,'cmd.color("teal","'+s+'")'  ],
+#           [ 1, '`151forest'  ,'cmd.color("forest","'+s+'")'  ],
+#           [ 1, '`611firebrick'   , 'cmd.color("firebrick","'+s+'")'  ],
+#           [ 1, '`631chocolate'   , 'cmd.color("chocolate","'+s+'")'  ],
+           [ 1, '`116density'     ,'cmd.color("density","'+s+'")'  ],
            [ 1, '`999white'       ,'cmd.color("white","'+s+'")'  ],
            [ 1, '`987wheat'       , 'cmd.color("wheat","'+s+'")'   ],
-           [ 1, '`555grey'    ,'cmd.color("grey","'+s+'")'  ]
+           [ 1, '`555grey'    ,'cmd.color("grey","'+s+'")'  ],
+           [ 1, '`222black'    ,'cmd.color("grey","'+s+'")'  ]
            ]
 
 def sele_action(s):
    return [[ 2, 'Actions:'       ,''                        ],     
-           [ 1, 'origin'         ,'cmd.origin("'+s+'")'          ],
+           [ 1, 'delete selection', 'cmd.delete("'+s+'")'          ],
+           [ 0, ''               ,''                             ],
            [ 1, 'zoom'           ,'cmd.zoom("'+s+'")'            ],
            [ 1, 'center'         ,'cmd.center("'+s+'")'            ],           
+           [ 1, 'origin'         ,'cmd.origin("'+s+'")'          ],
            [ 1, 'orient'         ,'cmd.orient("'+s+'")'          ],
            [ 0, ''               ,''                             ],
-           [ 1, 'delete selection', 'cmd.delete("'+s+'")'          ],
            [ 1, 'remove atoms'   ,'cmd.remove("'+s+'")'          ],
            [ 0, ''               ,''                             ],
+           [ 1, 'polar contacts'  ,
+             'cmd.dist("'+s+'_pc","'+s+'&elem n+o","same",3.2,quiet=1,mode=1,labels=0)'
+             ],                      
+           [ 0, ''               ,''                             ],
            [ 1, 'full residues'  ,'cmd.select("'+s+'","(byres '+s+')",show=1)'      ],
            [ 1, 'expand by 4 A'  ,'cmd.select("'+s+'","('+s+' expand 4)",show=1)' ],
            [ 1, 'expand by 8 A'  ,'cmd.select("'+s+'","('+s+' expand 8)",show=1)' ],
@@ -199,12 +220,15 @@ def sele_action(s):
 
 def mol_action(s):
    return [[ 2, 'Actions:'     , ''                       ],     
-           [ 1, 'origin'       , 'cmd.origin("'+s+'")'    ],
            [ 1, 'zoom'         , 'cmd.zoom("'+s+'")'      ],
            [ 1, 'center'         ,'cmd.center("'+s+'")'            ],
+           [ 1, 'origin'       , 'cmd.origin("'+s+'")'    ],
            [ 1, 'orient'       , 'cmd.orient("'+s+'")'    ],
            [ 0, ''          ,''                                              ],
-           [ 1, 'assign S.S.'  ,'util.ss("'+s+'")'        ],           
+           [ 1, 'assign S.S.'  ,'util.ss("'+s+'")'        ],
+           [ 1, 'polar contacts'  ,
+             'cmd.dist("'+s+'_pc","'+s+'&elem n+o","same",3.2,quiet=1,mode=1,labels=0)'
+             ],                      
            [ 0, ''          ,''                                              ],
            [ 1, 'freeze state'  ,'cmd.set("state",cmd.get_state(),"'+s+'")'        ],
            [ 1, 'thaw state'  ,'cmd.set("state",0,"'+s+'")'        ],           
@@ -226,16 +250,18 @@ def mol_action(s):
 
 def simple_action(s):
    return [[ 2, 'Actions:'     , ''                       ],
-           [ 1, 'origin'       , 'cmd.origin("'+s+'")'    ],
            [ 1, 'zoom'         , 'cmd.zoom("'+s+'")'      ],
+           [ 1, 'center'       , 'cmd.center("'+s+'")'    ],           
+           [ 1, 'origin'       , 'cmd.origin("'+s+'")'    ],
            [ 0, ''             , ''                       ],
            [ 1, 'delete'       , 'cmd.delete("'+s+'")'    ],
            ]
 
 def all_action(s):
    return [[ 2, 'Actions:'     , ''                      ],     
-           [ 1, 'origin'   , 'cmd.origin("all")'   ],
            [ 1, 'zoom'         , 'cmd.zoom("all")'     ],
+           [ 1, 'center'   , 'cmd.center("all")'   ],           
+           [ 1, 'origin'   , 'cmd.origin("all")'   ],
            [ 0, ''             , ''                      ],
            [ 1, 'delete everything'  , 'cmd.delete("all")'     ],
            [ 0, ''          ,''                                              ],
@@ -249,18 +275,26 @@ def all_action(s):
 def mol_labels(s):
    return [[ 2, 'Labels:'        , ''                                  ],
            [ 1, 'clear'          , 'cmd.label("'+s+'","\'\'")'         ],
+           [ 0, ''               , ''                                  ],
            [ 1, 'residues'       ,
-  'cmd.label("(name ca and (byres('+s+')))","\'%s-%s\'%(resn,resi)")'  ],
+  """cmd.label('''(name ca+C1*+C1' and (byres("""+s+""")))''','''"%s-%s"%(resn,resi)''')"""  ],
+           [ 1, 'chains'       ,   'util.label_chains("'+s+'")'  ],
+           [ 1, 'segments'       ,   'util.label_segments("'+s+'")'  ],           
+           [ 0, ''               , ''                                  ],           
            [ 1, 'name'           , 'cmd.label("'+s+'","name")'         ],
            [ 1, 'element'        , 'cmd.label("'+s+'","elem")'         ],           
-           [ 1, 'residue i.d.'    , 'cmd.label("'+s+'","resi")'         ],
            [ 1, 'residue name'  , 'cmd.label("'+s+'","resn")'         ],
+           [ 1, 'residue identifier'    , 'cmd.label("'+s+'","resi")'         ],
            [ 1, 'chain'         , 'cmd.label("'+s+'","chain")'         ],
-           [ 1, 'segment i.d.'       , 'cmd.label("'+s+'","segi")'         ],           
+           [ 1, 'segment identifier'       , 'cmd.label("'+s+'","segi")'         ],           
            [ 0, ''               , ''                                  ],
            [ 1, 'b-factor'       , 'cmd.label("'+s+'","\'%1.2f\'%b")'  ],
-           [ 1, 'partial charge' , 
-  'cmd.label("'+s+'","\'%1.4f\'%partial_charge")'                      ],
+           [ 1, 'occupancy'       , 'cmd.label("'+s+'","\'%1.2f\'%q")'  ],           
+           [ 0, ''               , ''                                  ],
+           [ 1, 'partial charge(.2f)' ,            
+  'cmd.label("'+s+'","\'%.2f\'%partial_charge")'                      ],
+           [ 1, 'partial charge(.4f)' , 
+  'cmd.label("'+s+'","\'%.4f\'%partial_charge")'                      ],
            [ 1, 'formal charge' , 
   'cmd.label("'+s+'","\'%d\'%formal_charge")'                      ],
            [ 0, ''               , ''                                  ],
