@@ -292,15 +292,18 @@ if __name__=='pymol.parser':
          for a in lst:
             print a
          # now append up to point of ambiguity
-         css = map(None,flist[0]) # common sub-string (css)
-         for a in flist:
-            ac = map(None,a)
-            tmp = css
+         if not len(flist):
             css = []
-            for c in range(len(tmp)):
-               if tmp[c]!=ac[c]:
-                  break
-               css.append(tmp[c])
+         else:
+            css = map(None,flist[0]) # common sub-string (css)
+            for a in flist:
+               ac = map(None,a)
+               tmp = css
+               css = []
+               for c in range(len(tmp)):
+                  if tmp[c]!=ac[c]:
+                     break
+                  css.append(tmp[c])
          css = filter(None,css)
          css = string.join(css,'')
          if len(css)>len(st):
@@ -319,23 +322,24 @@ if __name__=='pymol.parser':
       else:
          full = cmd.kwhash.interpret(re.sub(r" .*","",st))
          count = string.count(st,',') # which argument are we on
-         if count<len(cmd.auto_arg):      
-            if cmd.auto_arg[count].has_key(full): # autocomplete arguments
-               flag = 1
-               try:
-                  pre = re.sub(r"^[^ ]* ",' ',st,count=1) # trim command
-                  if re.search(r",",pre)!=None:
-                     pre = re.sub(r"[^\, ]*$","",pre,count=1) 
-                     pre = re.sub(r",\s*[^\, ]*$",", ",pre,count=1) # trim 1 arg
-                  else:
-                     pre = re.sub("[^ ]*$","",pre,count=1) # trim 1 arg               
-                  pre = re.sub(r"^ *",'',pre)
-                  pre = full+' '+pre
-                  pat = re.sub(r".*[\, ]",'',st)
-   #               print ":"+pre+":"+pat+":"
-                  result = apply(complete_sc,tuple([pat]+cmd.auto_arg[count][full]),{})
-               except:
-                  traceback.print_exc()
+         if cmd.is_string(full):
+            if count<len(cmd.auto_arg):
+               if cmd.auto_arg[count].has_key(full): # autocomplete arguments
+                  flag = 1
+                  try:
+                     pre = re.sub(r"^[^ ]* ",' ',st,count=1) # trim command
+                     if re.search(r",",pre)!=None:
+                        pre = re.sub(r"[^\, ]*$","",pre,count=1) 
+                        pre = re.sub(r",\s*[^\, ]*$",", ",pre,count=1) # trim 1 arg
+                     else:
+                        pre = re.sub("[^ ]*$","",pre,count=1) # trim 1 arg               
+                     pre = re.sub(r"^ *",'',pre)
+                     pre = full+' '+pre
+                     pat = re.sub(r".*[\, ]",'',st)
+      #               print ":"+pre+":"+pat+":"
+                     result = apply(complete_sc,tuple([pat]+cmd.auto_arg[count][full]),{})
+                  except:
+                     traceback.print_exc()
          if not flag: # otherwise fallback onto filename completion
             if(st[:1]=='@'):
                st=st[1:]
