@@ -67,7 +67,7 @@ PYMOL API
       return r
 
    def distance(name=None,selection1="(lb)",selection2="(rb)",cutoff=None,
-                mode=None,zoom=0,width=None,length=None,gap=None):
+                mode=None,zoom=0,width=None,length=None,gap=None,labels=1,quiet=1):
       '''
 DESCRIPTION
 
@@ -154,8 +154,11 @@ NOTES
          # now do the deed
          try:
             lock()
+            if selection2!="same":
+               selection2 = "("+selection2+")"
             r = _cmd.dist(str(nam),"("+str(selection1)+")",
-                          "("+str(selection2)+")",int(mode),float(cutoff))
+                          str(selection2),int(mode),float(cutoff),
+                          int(labels),int(quiet))
             if width!=None:
                cmd.set("dash_width",width,nam)
             if length!=None:
@@ -279,6 +282,15 @@ SEE ALSO
          unlock()
       return r
 
+   def get_movie_locked():
+      r = None
+      try:
+         lock()
+         r = _cmd.get_movie_locked()
+      finally:
+         unlock()
+      return r
+      
    def get_color_tuple(name):
       r = None
       try:
@@ -424,7 +436,28 @@ PYMOL API
       elif not quiet: print " cmd.get_area: %5.3f Angstroms^2."%r
       return r
 
-   def get_names(type='objects'):
+   def get_chains(selection="(all)",state=0,quiet=1):
+      '''
+      PRE-RELEASE functionality - API will change
+
+      state is currently ignored
+      '''
+      # preprocess selection
+      selection = selector.process(selection)
+      #
+      r = None
+      try:
+         lock()
+         r = _cmd.get_chains("("+str(selection)+")",int(state)-1)
+      finally:
+         unlock()
+      if r==None:
+         if cmd._raising(): raise QuietException
+      elif not quiet: print " cmd.get_chains: ",str(r)
+      return r
+
+
+   def get_names(type='objects',enabled_only=0):
       '''
 DESCRIPTION
 
@@ -453,7 +486,7 @@ SEE ALSO
          mode = 3
       try:
          lock()
-         r = _cmd.get_names(int(mode))
+         r = _cmd.get_names(int(mode),int(enabled_only))
       finally:
          unlock()
       return r
