@@ -227,6 +227,71 @@ if __name__=='pymol.setting':
       ray_shadows           =195
       ribbon_trace          =196
       security              =197
+      stick_transparency    =198
+      ray_transparency_shadows = 199
+      session_version_check = 200
+      ray_transparency_specular = 201
+      stereo_double_pump_mono = 202
+      sphere_solvent        = 203
+      mesh_quality          = 204
+      mesh_solvent          = 205
+      dot_solvent           = 206
+      ray_shadow_fudge      = 207
+      ray_triangle_fudge    = 208
+      debug_pick            = 209
+      dot_color             = 210
+      mouse_limit           = 211
+      mouse_scale           = 212
+      transparency_mode     = 213
+      clamp_colors          = 214
+      pymol_space_max_red   = 215
+      pymol_space_max_green = 216
+      pymol_space_max_blue  = 217
+      pymol_space_min_factor= 218
+      roving_origin         = 219
+      roving_lines          = 220
+      roving_sticks         = 221
+      roving_spheres        = 222
+      roving_labels         = 223
+      roving_delay          = 224
+      roving_selection      = 225
+      roving_byres          = 226
+      roving_ribbon         = 227
+      roving_cartoon        = 228
+      roving_polar_contacts = 229
+      roving_polar_cutoff   = 230
+      roving_nonbonded      = 231
+      float_labels          = 232
+      roving_detail         = 233
+      roving_nb_spheres     = 234
+      ribbon_color          = 235
+      cartoon_color         = 236
+      ribbon_smooth         = 237
+      auto_color            = 238
+      ray_interior_color    = 240
+      cartoon_highlight_color = 241
+      coulomb_units_factor  = 242
+      coulomb_dielectric    = 243
+      ray_interior_shadows  = 244
+      ray_interior_texture  = 245
+
+      roving_map1_name      = 246
+      roving_map2_name      = 247
+      roving_map3_name      = 248
+
+      roving_map1_level     = 249
+      roving_map2_level     = 250
+      roving_map3_level     = 251
+
+      roving_isomesh        = 252
+      roving_isosurface     = 253
+      scenes_changed        = 254
+      gaussian_lambda       = 255
+      pdb_standard_order    = 256
+      cartoon_smooth_first  = 257
+      cartoon_smooth_last   = 258
+      cartoon_smooth_cycles = 259
+      cartoon_flat_cycles   = 260
       
    setting_sc = Shortcut(SettingIndex.__dict__.keys())
 
@@ -365,8 +430,8 @@ NOTES
             except:
                if(_feedback(fb_module.cmd,fb_mask.debugging)):
                   traceback.print_exc()
-                  raise QuietException
-               print "Error: unable to read setting value."
+                  print "Error: unable to read setting value."
+               raise QuietException
          finally:
             unlock()
       return r
@@ -426,16 +491,43 @@ PYMOL API
          lock()
          r = _cmd.get_setting_tuple(i,str(object),int(state)-1)
          typ = r[0]
-         if typ<3:
+         if typ<3: # boolean, int
             r = int(r[1][0])
-         elif typ<4:
+         elif typ<4: # float
             r = r[1][0]
-         elif typ<5:
+         elif typ<5: # vector
             r = r[1]
+         else:
+            r = r[1] # color or string
       finally:
          unlock()
       return r
 
+   def get(name,object='',state=0,quiet=1):
+      r = None
+      state = int(state)
+      if is_string(name):
+         i = _get_index(name)
+      else:
+         i = int(name)
+      if i<0:
+         print "Error: unknown setting"
+         raise QuietException
+      try:
+         lock()
+         r = _cmd.get_setting_text(i,str(object),state-1)
+      finally:
+         unlock()
+      if r!=None:
+         if not quiet:
+            if(object==''):
+               print " get: %s = %s"%(name,r)
+            elif state<=0:
+               print " get: %s = %s in object %s"%(name,r,object)
+            else:
+               print " get: %s = %s in object %s state %d"%(name,r,object,state)
+      return r
+   
    def get_setting_tuple(name,object='',state=0): # INTERNAL
       r = None
       if is_string(name):      i = _get_index(name)
