@@ -24,77 +24,103 @@ mload = movie.load
 mrock = movie.rock
 mroll = movie.roll
 
-def cbag(selection="(all)"):
+def cbag(selection="(all)",quiet=1):
    s = str(selection)
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("carbon","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("carbon","(elem C and "+s+")",quiet=quiet)
 
-def cbac(selection="(all)"):
+def cbac(selection="(all)",quiet=1):
    s = str(selection)
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("cyan","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("cyan","(elem C and "+s+")",quiet=quiet)
 
-def cbay(selection="(all)"):
+def cbay(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("yellow","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("yellow","(elem C and "+s+")",quiet=quiet)
 
-def cbas(selection="(all)"):
+def cbas(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("salmon","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("salmon","(elem C and "+s+")",quiet=quiet)
 
-def cbap(selection="(all)"):
+def cbap(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("purple","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("purple","(elem C and "+s+")",quiet=quiet)
 
-def cbak(selection="(all)"):
+def cbak(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("pink","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("pink","(elem C and "+s+")",quiet=quiet)
 
-def cbaw(selection="(all)"):
+def cbam(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("hydrogen","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("lightmagenta","(elem C and "+s+")",quiet=quiet)
 
-def cbab(selection="(all)"):
+def cbaw(selection="(all)",quiet=1):
    s = str(selection)   
-   cmd.color("magenta","("+s+")")
-   cmd.color("oxygen","(elem O and "+s+")")
-   cmd.color("nitrogen","(elem N and "+s+")")
-   cmd.color("sulfur","(elem S and "+s+")")
-   cmd.color("hydrogen","(elem H and "+s+")")
-   cmd.color("slate","(elem C and "+s+")")
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem C and "+s+")",quiet=quiet)
+
+def cbab(selection="(all)",quiet=1):
+   s = str(selection)   
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("slate","(elem C and "+s+")",quiet=quiet)
+
+def cbao(selection="(all)",quiet=1):
+   s = str(selection)   
+   cmd.color("magenta","("+s+")",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)
+   cmd.color("brightorange","(elem C and "+s+")",quiet=quiet)
+
+def cnc(selection="(all)",quiet=1):
+   s = str(selection)
+   cmd.color("magenta","("+s+" and not elem c)",quiet=quiet)
+   cmd.color("oxygen","(elem O and "+s+")",quiet=quiet)
+   cmd.color("nitrogen","(elem N and "+s+")",quiet=quiet)
+   cmd.color("sulfur","(elem S and "+s+")",quiet=quiet)
+   cmd.color("hydrogen","(elem H and "+s+")",quiet=quiet)   
 
 def performance(mode):
    mode = int(mode)
@@ -107,6 +133,7 @@ def performance(mode):
       cmd.set('sphere_quality',2)
       cmd.set('cartoon_sampling',14)
       cmd.set('ribbon_sampling',10)
+      cmd.set('transparency_mode',1)
       cmd.do("rebuild")
    elif mode==33:
       cmd.set('line_smooth',1)         
@@ -116,6 +143,7 @@ def performance(mode):
       cmd.set('stick_quality',8)
       cmd.set('sphere_quality',1)
       cmd.set('cartoon_sampling',7)
+      cmd.set('transparency_mode',1)
       cmd.do("rebuild")
    elif mode==66: # good perfomance
       cmd.set('line_smooth',0)
@@ -125,6 +153,7 @@ def performance(mode):
       cmd.set('stick_quality',8)
       cmd.set('sphere_quality',1)
       cmd.set('cartoon_sampling',6)
+      cmd.set('transparency_mode',2)
       cmd.do("rebuild")         
    else: # maximum performance
       cmd.set('line_smooth',0)
@@ -134,8 +163,58 @@ def performance(mode):
       cmd.set('stick_quality',5)
       cmd.set('sphere_quality',0)
       cmd.set('cartoon_sampling',3)
+      cmd.set('transparency_mode',0)
       cmd.do("rebuild")         
 
+
+
+def label_chains(sele="all"):
+   pymol.stored._cs = []
+   last = None
+   save = ()
+   list = []
+   cmd.iterate(sele,"stored._cs.append((model,chain,index))")
+   for a in pymol.stored._cs:
+      if (a[0:2]!=save):
+         list.append(last)
+         list.append(a)
+         save = a[0:2]
+      last = a
+   if len(list):
+      list.append(last)
+   list = filter(None,list)
+   for a in list:
+      if(a[1]==''):
+         cmd.label("%s`%d"%(a[0],a[2]),'''"chain ''"''',quiet=1)         
+      elif(a[1]==' '):
+         cmd.label("%s`%d"%(a[0],a[2]),'''"chain ' '"''',quiet=1)         
+      else:
+         cmd.label("%s`%d"%(a[0],a[2]),"'chain '+chain",quiet=1)
+
+def label_segments(sele="all"):
+   pymol.stored._cs = []
+   last = None
+   save = ()
+   list = []
+   cmd.iterate(sele,"stored._cs.append((model,segi,index))")
+   for a in pymol.stored._cs:
+      if (a[0:2]!=save):
+         list.append(last)
+         list.append(a)
+         save = a[0:2]
+      last = a
+   if len(list):
+      list.append(last)
+   list = filter(None,list)
+   for a in list:
+      if(a[1]==''):
+         cmd.label("%s`%d"%(a[0],a[2]),'''"segi ''"''',quiet=1)         
+      elif(a[1]==' '):
+         cmd.label("%s`%d"%(a[0],a[2]),'''"segi ' '"''',quiet=1)         
+      else:
+         cmd.label("%s`%d"%(a[0],a[2]),"'segi '+segi",quiet=1)
+
+   
 def hide_sele():
    arg = cmd.get_names("selections")
    for a in arg:
@@ -147,22 +226,34 @@ def hide_sele():
 #            "((%s) and ((%s) around %4.2f) and elem N,O)"%(b,a,cutoff),
 #            cutoff)
 
-def cbc(selection='(all)',first_color=7): # NOT THREAD SAFE
+def cbc(selection='(all)',first_color=7,quiet=1): 
    '''
    Color all chains a different color
    '''
-   pymol.stored.chain = {}
-   cmd.iterate("(%s)"%selection,"stored.chain[chain]=1")
    c = first_color
-   for a in pymol.stored.chain.keys():
-      if len(a):
-         print ("%d,(chain %s)"%(c,a))
-         cmd.color("%d"%c,"(chain %s)"%a)
+   for a in cmd.get_chains(selection):
+      if len(string.strip(a)):
+         if not quiet: print (" util.cbc: color %d,(chain %s)"%(c,a))
+         cmd.color("%d"%c,"(chain %s and (%s))"%(a,selection),quiet=quiet)
+         c = c + 1
+      elif len(a): # note, PyMOL's selection language can't handle this right now
+         if not quiet: print (" util.cbc: color %d,(chain ' ')"%(c))
+         cmd.color("%d"%c,"(chain '' and (%s))"%selection,quiet=quiet)
          c = c + 1
       else:
-         print ("%d,(chain '')"%(c))
-         cmd.color("%d"%c,"(chain '')")
+         if not quiet: print (" util.cbc: color %d,(chain '')"%(c))
+         cmd.color("%d"%c,"(chain '' and (%s))"%selection,quiet=quiet)
          c = c + 1
+
+def chainbow(selection='(all)',first_color=7): # NOT THREAD SAFE
+   '''
+   Color all chains in rainbow
+   '''
+   for a in cmd.get_chains(selection):
+      if len(a):
+         cmd.spectrum('count',selection="(chain %s and (%s))"%(a,selection),byres=1)
+      else:
+         cmd.spectrum('count',selection="(chain '' and (%s))"%selection,byres=1)
          
 color_chains = cbc
 
@@ -222,16 +313,16 @@ def ray_shadows(mode):
       cmd.set('reflect',0.75) # was 0.70
       cmd.set('direct',0.06)
       cmd.set('power',0.3)
-      cmd.set('gamma',1.43) # was 1.5
+      cmd.set('gamma',1.5) # was 1.43
    elif mode=='black': # best for light backgrounds
       cmd.set('power',0.3)
       cmd.set('spec_reflect',1.1)
       cmd.set('spec_power',90) 
-      cmd.set('ambient',0.00)
+      cmd.set('ambient',0.001)
       cmd.set('reflect',0.8)
       cmd.set('direct',0.00)
       cmd.set('reflect_power',1.7)
-      cmd.set('gamma',1.55) 
+      cmd.set('gamma',1.8) # was 1.55
 
 def ff_copy(src,dst): # NOT THREAD SAFE
    pymol._rcopy = pymol.Scratch_Storage()
