@@ -24,16 +24,25 @@ if __name__=='pymol.viewing':
    import parsing
 
    import cmd
+   
    from cmd import _cmd,lock,unlock,Shortcut,QuietException,_raising, \
         _feedback,fb_module,fb_mask, \
-        repres,repres_sc, \
-        toggle_dict,toggle_sc,stereo_dict,stereo_sc
+        repres,repres_sc, is_string, is_list, \
+        toggle_dict,toggle_sc,stereo_dict,stereo_sc, \
+        palette_dict ,palette_sc
 
+   rep_list = [ "lines","sticks","spheres",
+                "dots","surface","mesh",
+                "nonbonded", "nb_spheres",
+                "cartoon","ribbon","labels"]
 
+   view_sc = Shortcut(['store','recall','clear'])
    view_dict = {}
-   view_sc = Shortcut(['store','recall'])
    view_dict_sc = Shortcut([])
 
+   scene_dict = {}
+   scene_dict_sc = Shortcut([])
+
    def zoom(selection="all",buffer=0.0,state=0,complete=0):
       '''
 DESCRIPTION
@@ -261,6 +270,7 @@ SEE ALSO
       return r
 
 
+
    def move(axis,distance):
       '''
 DESCRIPTION
@@ -366,7 +376,7 @@ DESCRIPTION
    The available representations are:
 
       lines     spheres   mesh      ribbon     cartoon
-      sticks    dots      surface   labels
+      sticks    dots      surface   labels     extent
       nonbonded nb_spheres 
 
 USAGE
@@ -533,7 +543,7 @@ API USAGE
       r = r[0:3]+r[4:7]+r[8:11]+r[16:25]
       return r
 
-   def set_view(view):
+   def set_view(view,quiet=1):
       '''
 DESCRIPTION
 
@@ -571,7 +581,7 @@ PYMOL API
                0.0,0.0,0.0,1.0,
                float(view[ 9]),float(view[10]),float(view[11]),
                float(view[12]),float(view[13]),float(view[14]),
-               float(view[15]),float(view[16]),float(view[17])))
+               float(view[15]),float(view[16]),float(view[17])),quiet)
          finally:
             unlock()
       return r
@@ -604,29 +614,278 @@ SEE ALSO
 
    set_view, get_view
       '''
+      global view_dict,view_dict_sc
+   
       if key=='*':
-         print " view: stored views:"
-         lst = view_dict.keys()
-         lst.sort()
-         parsing.dump_str_list(lst)
+         action = view_sc.auto_err(action,'action')
+         if action=='clear':
+            view_dict = {}
+            view_dict_sc = Shortcut(view_dict.keys())                        
+         else:
+            print " view: stored views:"
+            lst = view_dict.keys()
+            lst.sort()
+            parsing.dump_str_list(lst)
+            
       else:
          action = view_sc.auto_err(action,'action')
          if action=='recall':
             key = view_dict_sc.auto_err(key,'view')
             set_view(view_dict[key])
-            if _feedback(fb_module.scene,fb_mask.blather): # redundant
-               print " view: recalled."
+            if _feedback(fb_module.scene,fb_mask.actions): # redundant
+               print " view: \"%s\" recalled."%key
          elif action=='store':
             view_dict_sc.append(key)
             view_dict[key]=cmd.get_view(0)
             if _feedback(fb_module.scene,fb_mask.actions):
-               print " view: view stored as '%s'."%key
+               print " view: view stored as \"%s\"."%key
+         elif action=='clear':
+            key = view_dict_sc.auto_err(key,'view')
+            if view_dict.has_key(key):
+               del view_dict[key]
+               view_dict_sc = Shortcut(view_dict.keys())            
+               if _feedback(fb_module.scene,fb_mask.actions): # redundant
+                  print " view: '%s' deleted."%key
 
+
+   def get_vis():
+      try:
+         lock()
+         r = _cmd.get_vis()
+      finally:
+         unlock()
+      return r
+
+   def set_vis(dict):
+      try:
+         lock()         
+         r = _cmd.set_vis(dict)
+      finally:
+         unlock()
+      return r
+
+   def get_colorection(key):
+      try:
+         lock()         
+         r = _cmd.get_colorection(key)
+      finally:
+         unlock()
+      return r
+
+   def set_colorection(dict,key):
+      try:
+         lock()         
+         r = _cmd.set_colorection(dict,key)
+      finally:
+         unlock()
+      return r
+
+   def del_colorection(dict,key):
+      try:
+         lock()         
+         r = _cmd.del_colorection(dict,key)
+      finally:
+         unlock()
+      return r
+
+   def get_scene_dict():
+      try:
+         lock()
+         cpy = copy.deepcopy(scene_dict)
+      finally:
+         unlock()
+      return cpy
+   
+   def scene(key,action='recall',message=None,
+             view=1,color=1,active=1,rep=1,frame=1):
+      '''
+DESCRIPTION
+
+   "scene" makes it possible to save and restore scenes
+   scene within a single session.
+
+USAGE
+
+   scene key [,action [,message ]]
+   scene *
+
+   key can be any string
+   action should be 'store' or 'recall' (default: 'recall')
+
+PYMOL API
+
+   cmd.scene(string key,string action,string-or-list message)
+
+EXAMPLES
+
+   scene 0,store
+   scene 0
+
+SEE ALSO
+
+   view, set_view, get_view
+      '''
+      global scene_dict,scene_dict_sc
+
+      try:
+         view = int(view)
+         rep = int(rep)
+         color = int(color)
+         active = int(active)
+         frame = int(frame)
+         lock() # manipulating global data, so need lock
+         
+         if key=='*':
+            action = view_sc.auto_err(action,'action')
+            if action=='clear':
+
+               for key in scene_dict.keys():
+                  # free selections
+                  list = scene_dict[key]
+                  if len(list)>3:
+                     colorection = list[3]
+                     if colorection!=None:
+                        cmd.del_colorection(colorection,key) 
+                  name = "_scene_"+key+"_*"
+                  cmd.delete(name)
+               scene_dict = {}
+               scene_dict_sc = Shortcut(scene_dict.keys())                        
+            else:
+               print " scene: stored scenes:"
+               lst = scene_dict.keys()
+               lst.sort()
+               parsing.dump_str_list(lst)
+         else:
+            action = view_sc.auto_err(action,'action')
+            if action=='recall':
+               cmd.set("scenes_changed",1,quiet=1);
+               key = scene_dict_sc.auto_err(key,'scene')
+               list = scene_dict[key]
+               ll = len(list)
+               if (ll>0) and (view):
+                  if list[0]!=None:
+                     set_view(list[0])
+               if (ll>1) and (active):
+                  if list[1]!=None:
+                     cmd.disable()
+                     cmd.set_vis(list[1])
+               if (ll>2) and (frame):
+                  if list[2]!=None:
+                     cmd.frame(list[2])
+               if (ll>3) and (color):
+                  if list[3]!=None:
+                     cmd.set_colorection(list[3],key)
+               if (ll>4) and (rep):
+                  if list[4]==None:
+                     rep = 0
+               if (ll>5) and (message==None):
+                  if list[5]!=None:
+                     message=list[5]
+               if rep!=0:
+                  cmd.hide("(all)")
+                  for rep_name in rep_list:
+                     name = "_scene_"+key+"_"+rep_name
+                     cmd.show(rep_name,name)
+               replace_flag = 0
+               wiz = cmd.get_wizard()
+               if wiz!=None:
+                  if str(wiz.__class__) == 'pymol.wizard.message.Message':
+                     if hasattr(wiz,'from_scene'):
+                        replace_flag = 1
+               mess_flag = 0
+               if message!=None:
+                  if is_string(message):
+                     if len(message):
+                        if(replace_flag):
+                           cmd.replace_wizard("message",message)
+                        else:
+                           cmd.wizard("message",message)
+                        cmd.get_wizard().from_scene = 1
+                        mess_flag = 1
+                  if is_list(message):
+                     if len(message):
+                        if(replace_flag):
+                           apply(cmd.replace_wizard,("message",)+tuple(message))
+                        else:
+                           apply(cmd.wizard,("message",)+tuple(message))
+                        cmd.get_wizard().from_scene = 1
+                        mess_flag = 1
+               if replace_flag and not mess_flag:
+                  cmd.wizard()
+               if _feedback(fb_module.scene,fb_mask.actions): # redundant
+                  print " scene: \"%s\" recalled."%key
+            elif action=='store':
+               if not scene_dict.has_key(key):
+                  scene_dict_sc.append(key)
+               else: # get rid of existing one (if exists)
+                  list = scene_dict[key]
+                  if len(list)>3:
+                     colorection = list[3]
+                     if colorection!=None:
+                        cmd.del_colorection(colorection,key) # important -- free RAM
+                  name = "_scene_"+key+"_*"
+                  cmd.delete(name)
+               entry = []
+               if view:
+                  entry.append(cmd.get_view(0))
+               else:
+                  entry.append(None);
+               if active:
+                  entry.append(cmd.get_vis())
+               else:
+                  entry.append(None)
+               if frame:
+                  entry.append(cmd.get_frame())
+               else:
+                  entry.append(None)
+               if color:
+                  entry.append(cmd.get_colorection(key))
+               else:
+                  entry.append(None)
+               if rep:
+                  entry.append(1)
+                  for rep_name in rep_list:
+                     name = "_scene_"+key+"_"+rep_name
+                     cmd.select(name,"rep "+rep_name)
+               else:
+                  entry.append(None)
+               if is_string(message):
+                  if len(message)>1:
+                     if (message[0:1] in [ '"',"'"] and
+                         message[-1:] in [ '"',"'"]):
+                        message=message[1:-1]
+                     else:
+                        message = string.split(message,"\n")
+               entry.append(message)
+               scene_dict[key]=entry
+               if _feedback(fb_module.scene,fb_mask.actions):
+                  print " scene: scene stored as \"%s\"."%key
+               cmd.set("scenes_changed",1,quiet=1);
+            elif action=='clear':
+               key = scene_dict_sc.auto_err(key,'view')
+               if scene_dict.has_key(key):
+
+                  list = scene_dict[key]
+                  if len(list)>3:
+                     colorection = list[3]
+                     if colorection!=None:
+                        cmd.del_colorection(colorection,key) # important -- free RAM
+                  
+                  cmd.set("scenes_changed",1,quiet=1);               
+                  del scene_dict[key]
+                  name = "_scene_"+key+"_*"
+                  cmd.delete(name)
+                  scene_dict_sc = Shortcut(scene_dict.keys())            
+                  if _feedback(fb_module.scene,fb_mask.actions):
+                     print " scene: '%s' deleted."%key
+      finally:
+         unlock()
+         
+               
    def session_save_views(session):
       session['view_dict']=copy.deepcopy(view_dict)
       return 1
 
-
    def session_restore_views(session):
       global view_dict,view_dict_sc
       if session.has_key('view_dict'):
@@ -640,7 +899,24 @@ SEE ALSO
    if session_save_views not in pymol._session_save_tasks:
       pymol._session_save_tasks.append(session_save_views)
 
-   def stereo(state='on'):
+   def session_save_scenes(session):
+      session['scene_dict']=copy.deepcopy(scene_dict)
+      return 1
+
+   def session_restore_scenes(session):
+      global scene_dict,scene_dict_sc
+      if session.has_key('scene_dict'):
+         scene_dict=copy.deepcopy(session['scene_dict'])
+         scene_dict_sc = Shortcut(scene_dict.keys())
+      return 1
+
+   if session_restore_scenes not in pymol._session_restore_tasks:
+      pymol._session_restore_tasks.append(session_restore_scenes)
+
+   if session_save_scenes not in pymol._session_save_tasks:
+      pymol._session_save_tasks.append(session_save_scenes)
+
+   def stereo(state='on',quiet=1):
       '''
 DESCRIPTION
 
@@ -669,9 +945,11 @@ PYMOL API
          lock()
          if state>1:
             if state==2: # cross-eye
-               cmd.set("stereo_mode","2",quiet=1)
+               cmd.set("stereo_mode","2",quiet=quiet)
             elif state==3: # quad
-               cmd.set("stereo_mode","1",quiet=1)
+               cmd.set("stereo_mode","1",quiet=quiet)
+            elif state==4: # wall-eye
+               cmd.set("stereo_mode","3",quiet=quiet)
             state=1
          if not _cmd.stereo(state):
             print "Error: Selected stereo mode is not available."
@@ -762,7 +1040,7 @@ PYMOL API
          unlock()
       return r
 
-   def label(selection="(all)",expression=""):
+   def label(selection="(all)",expression="",quiet=1):
       '''
 DESCRIPTION
 
@@ -796,9 +1074,9 @@ EXAMPLES
       try:
          lock()
          if len(str(expression))==0:
-            r= _cmd.label("("+str(selection)+")",'')
+            r= _cmd.label("("+str(selection)+")",'',quiet)
          else:
-            r = _cmd.label("("+str(selection)+")",'label='+str(expression))
+            r = _cmd.label("("+str(selection)+")",'label='+str(expression),quiet)
       finally:
          unlock()   
       return r
@@ -909,7 +1187,7 @@ NOTES
          unlock()
       return r
 
-   def ray(width=0,height=0,renderer=-1):
+   def ray(width=0,height=0,renderer=-1,angle=0.0,shift=0.0):
       '''
 DESCRIPTION
 
@@ -919,8 +1197,10 @@ DESCRIPTION
 
 USAGE
 
-   ray [width,height [,renderer ]]
+   ray [width,height [,renderer [,angle [,shift ]]]
 
+   angle and shift can be used to generate matched stereo pairs
+   
 EXAMPLES
 
    ray
@@ -929,7 +1209,7 @@ EXAMPLES
 
 PYMOL API
 
-   cmd.ray(int width,int height,int renderer=-1,string prefix)
+   cmd.ray(int width,int height,int renderer=-1,float shift=0)
 
 NOTES
 
@@ -948,7 +1228,8 @@ SEE ALSO
       '''
       try:
          lock()   
-         r = _cmd.render(int(width),int(height),int(renderer))
+         r = _cmd.render(int(width),int(height),
+                         int(renderer),float(angle),float(shift))
       finally:
          unlock()
       return r
@@ -1099,7 +1380,7 @@ SEE ALSO
       finally:
          unlock()
 
-   def color(color,selection="(all)"):
+   def color(color,selection="(all)",quiet=1):
       '''
 DESCRIPTION
 
@@ -1125,14 +1406,55 @@ EXAMPLES
       #
       try:
          lock()
-         r = _cmd.color(str(color),str(selection),0)
+         r = _cmd.color(str(color),str(selection),0,int(quiet))
       finally:
          unlock()
       if not r:
          if _raising(): raise QuietException
       return r
 
+   def spectrum(expression="count",
+                palette="rainbow",
+                selection="(all)",
+                minimum=None,
+                maximum=None,
+                byres=0,quiet=1):
+      '''
+DESCRIPTION
 
+   "spectrum" colors atoms using a spectrum
+   
+USAGE
+
+PYMOL API
+
+EXAMPLES 
+
+      '''
+
+      palette = palette_sc.auto_err(palette,'palette')
+      
+      (prefix,digits,first,last) = palette_dict[str(palette)]
+
+      if (maximum==None) or (minimum==None):
+         minimum = 0 # signal to auto-adjust levels
+         maximum = -1
+
+      # preprocess selection
+      selection = selector.process(selection)
+      #
+      try:
+         lock()
+         r = _cmd.spectrum(str(selection),str(expression),
+                           float(minimum),float(maximum),
+                           int(first),int(last),str(prefix),
+                           int(digits),int(byres),int(quiet))
+      finally:
+         unlock()
+      if not r:
+         if _raising(): raise QuietException
+      return r
+   
    def set_color(name,rgb):
       '''
 DESCRIPTION
@@ -1177,4 +1499,3 @@ EXAMPLES
 
 
 
-
